@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/cgi_sql_common.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -78,7 +82,7 @@ module SiSU_CGI_SQL
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997 - 2013, Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -292,8 +296,8 @@ module SiSU_CGI_SQL
             @date_modified=q['dtm'] if q['dtm']=~/\S/
             @date_available=q['dta'] if q['dta']=~/\S/
             @date_valid=q['dtv'] if q['dtv']=~/\S/
-            @filename=if q['doc'] and q['search'] !~/search db/; q['doc']
-            elsif q['fns']=~/\S/; q['fns']
+            @filename=if q['doc'] and q['search'] !~/search db/ then q['doc']
+            elsif q['fns']=~/\S/                                then q['fns']
             end
             @@limit=q['ltd'] if q['ltd']=~/\d+/  # 1000
             @@offset=q['off'] if q['off']=~/\d+/ # 0
@@ -301,19 +305,19 @@ module SiSU_CGI_SQL
         end
         def text_to_match(identifier='')
           m={
-            :string => /#{identifier}\s*(.+?)/,
-            :string => /#{identifier}\s*(.+?)(?:;|\n|\r|$)/,
-            :word => /#{identifier}[\s(]*(\S+)/
+            string: /#{identifier}\s*(.+?)/,
+            string: /#{identifier}\s*(.+?)(?:;|\n|\r|$)/,
+            word: /#{identifier}[\s(]*(\S+)/
           }
           search_string=if @search_field =~m[:word]
-            search_string=if @search_field =~m[:braces]; m[:braces].match(@search_field)[1]
-            elsif @search_field =~m[:string];            m[:string].match(@search_field)[1]
+            search_string=if @search_field =~m[:braces] then m[:braces].match(@search_field)[1]
+            elsif @search_field =~m[:string]            then m[:string].match(@search_field)[1]
             else
               str=m[:word].match(@search_field)[1]
               str=str.gsub(/[()]/,'')
               str
             end
-            search_string=search_string.strip.search_string.gsub(/\s+/,'+')
+            search_string=search_string.strip.gsub(/\s+/,'+')
           #else
           #  "__"
           end
@@ -328,10 +332,10 @@ module SiSU_CGI_SQL
         def initialize(conn,search_for,q,c)
           @conn=conn
           @text_search_flag=false
-          @sql_statement={ :body => '', :endnotes => '', :range => '' }
+          @sql_statement={ body: '', endnotes: '', range: '' }
           #@offset||=@@offset
           #@offset+=@@limit
-          search={ :text => [], :endnotes => [] }
+          search={ text: [], endnotes: [] }
           cse=(c =~/\S/) ? true : false
           st=DBI_SearchString.new('doc_objects.clean',search_for.text1,q['s1'],cse).string
           se=DBI_SearchString.new('endnotes.clean',search_for.text1,q['s1'],cse).string
@@ -512,7 +516,7 @@ module SiSU_CGI_SQL
               </center>}
             end
           else
-            if page.to_s =~ /^1$/; ''
+            if page.to_s =~ /^1$/ then ''
             elsif page.to_s =~ /^2$/
               %{<br /><center>
               <a href="#{can.previous}">
@@ -558,7 +562,7 @@ module SiSU_CGI_SQL
     <br />
     <a href="http://www.jus.uio.no/sisu" >
     <b>#{v[:project]}</b></a> <sup>&copy;</sup> Ralph Amissah
-    1993, current 2012.
+    1993, current 2013.
     All Rights Reserved.
     <br />
     <a href="http://www.jus.uio.no/sisu" >
@@ -594,7 +598,7 @@ module SiSU_CGI_SQL
     <br />Standard SiSU meta-markup syntax, and the
     <br />Standard SiSU <u>object citation numbering</u> and system, (object/text positioning system)
   <br />
-    <sup>&copy;</sup> Ralph Amissah 1997, current 2012.
+    <sup>&copy;</sup> Ralph Amissah 1997, current 2013.
     All Rights Reserved.
   </font></p>
 </td></tr>
@@ -650,9 +654,9 @@ module SiSU_CGI_SQL
       @counters_txt,@counters_endn,@sql_select_body,@sql_select_endnotes='','','',''
       FCGI.each_cgi do |cgi|
         begin # all code goes in begin section
-          @search={ :text => [], :endnotes => [] }
+          @search={ text: [], endnotes: [] }
           q=CGI.new
-          @db=if cgi['db'] =~/\S+/;
+          @db=if cgi['db'] =~/\S+/
             @stub=/#{@db_name_prefix}(\S+)/.match(cgi['db'])[1]
             cgi['db']
           else
@@ -661,13 +665,13 @@ module SiSU_CGI_SQL
           end
           checked_url,checked_stats,checked_searched,checked_tip,checked_case,checked_echo,checked_sql,checked_all,checked_none,checked_selected,checked_default,selected_db='','','','','','','','',''
           result_type=(cgi['view']=~/text/) \
-          ? result_type={ :index => '', :text => 'checked'}
-          : result_type={ :index => 'checked', :text => ''}
+          ? result_type={ index: '', text: 'checked'}
+          : result_type={ index: 'checked', text: ''}
           @@limit=if cgi['sql_match_limit'].to_s=~/2500/
-            checked_sql_limit={ :l1000 => '', :l2500 => 'checked'}
+            checked_sql_limit={ l1000: '', l2500: 'checked'}
             '2500'
           else
-            checked_sql_limit={ :l1000 => 'checked', :l2500 => ''}
+            checked_sql_limit={ l1000: 'checked', l2500: ''}
             '1000'
           end
           checked_echo='checked' if cgi['echo'] =~/\S/
@@ -1024,8 +1028,9 @@ module SiSU_CGI_SQL
               if cgi['view']=~/text/ \
               or (cgi['view']!~/index/ and cgi['search'] !~/search db/)      #% txt endnotes
                 @counter_endn_ocn+=1
-                matched_endnote=(@search_regx.to_s.class==String && @search_regx.to_s=~/\S\S+/) \
-                ? matched=e['body'].gsub(/(<a\s+href="https?:\/\/[^><\s]+#{@search_regx}[^>]+?>|#{@search_regx})/mi,%{<span style="background-color: #{@color_match}">\\1</span>})
+                matched_endnote=(@search_regx.to_s.is_a?(String) \
+                && @search_regx.to_s=~/\S\S+/) \
+                ? (matched=e['body'].gsub(/(<a\s+href="https?:\/\/[^><\s]+#{@search_regx}[^>]+?>|#{@search_regx})/mi,%{<span style="background-color: #{@color_match}">\\1</span>}))
                 : e['body']
                 output=%{#{title}<hr><font size="2">note <b><a href="#{path_endnotes(location,@ln)}#_#{e['nr']}">#{e['nr']}</a></b> referred to from ocn <a href="#{path_html_doc(location,@ln)}##{e['ocn']}">#{e['ocn']}</a>:</font> #{matched_endnote}}
               else #elsif cgi['view']=~/index/      #doc #FIX                           #% idx endnotes
