@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/composite.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -160,8 +164,8 @@ module SiSU_Assemble
       file[:prepared] << "\n% |#{fni}|@|^|>>ok\n"
       @code_flag=false
       insert_array.each do |i|
-        @code_flag=if i =~/^code\{/; true
-        elsif i =~/^\}code/; false
+        @code_flag=if i =~/^code\{/ then true
+        elsif i =~/^\}code/         then false
         else @code_flag
         end
         if not @code_flag \
