@@ -9,7 +9,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -49,6 +49,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/constants.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -57,6 +61,7 @@
 
 =end
 #Ax,Xx,Mx,Rx,Hx,Dx,Px,Ep,Db,Gt,Tex=Array.new(11){{}}
+YEAR='2013'
 Sfx={ txt: '.txt', html: '.html', xhtml: '.xhtml', xml: '.xml', epub: '.epub', epub_xhtml: '.xhtml', odt: '.odt', pdf: '.pdf'}
 Ax={
   tab:                       "\t",
@@ -97,8 +102,8 @@ Mx={
   br_nl:                     '╲',                                              #lB ▌ 』  ┘
   br_paragraph:              '█',                                              #FB █  9608 # PP ∥  8741 #▐  #'┘' #'¶' #FB █  9608  lB ▌  9612   RB ▐  9616
   br_obj:                    'break_obj',
-  br_page:                   'break_page',
-  br_page_new:               'break_page_new',
+  br_page:                   '┼',
+  br_page_new:               '╋',
   lnk_o:                     '⌠',          lnk_c:               '⌡',           #'⌈' '⌋' '⌠' '⌡' #Mx[:lnk_o: '◁'; Mx[:lnk_c: '▷' #‹ ›
   url_o:                     '「',         url_c:               '」',
   rel_o:                     '⌈',          rel_c:               '⌋',
@@ -202,25 +207,25 @@ Ep={
   f_opf:                     'content.opf',
 }
 Db={
-  name_prefix:               "SiSU#{SiSU_version_dir}e_",
-  name_prefix_db:            "sisu_#{SiSU_version_dir}e_",
-  col_title:                 800,
-  col_title_part:            400,
-  col_title_edition:         10,
-  col_name:                  600,
-  col_creator_misc_short:    100,
-  col_language:              100,
-  col_language_char:         6,
-  col_date_text:             10,
-  col_classify_txt_long:     600,
-  col_classify_txt_short:    600,
-  col_classify_short:        200,
-  col_classify_identify:     256,
-  col_classify_library:      30,
-  col_classify_small:        16,
-  col_filename:              256,
-  col_digest:                64,
-  col_filesize:              10,
+  name_prefix:               "SiSU#{SiSU_version_dir}f_",
+  name_prefix_db:            "sisu_#{SiSU_version_dir}f_",
+  col_title:                  800,
+  col_title_part:             400,
+  col_title_edition:           10,
+  col_name:                   600,
+  col_creator_misc_short:     100,
+  col_language:               100,
+  col_language_char:            6,
+  col_date_text:               10,
+  col_classify_txt_long:      600,
+  col_classify_txt_short:     600,
+  col_classify_short:         200,
+  col_classify_identify:      256,
+  col_classify_library:        30,
+  col_classify_small:          16,
+  col_filename:               256,
+  col_digest:                  64,
+  col_filesize:                10,
   col_info_note:             2500,
 }
 Gt={
@@ -240,6 +245,27 @@ Gt={
   conf:                      'doc/_sisu',
   skin:                      'doc/_sisu/skin',                                  #Gt[:skin: 'conf/skin/doc'
 }
+ANSI_C={
+  red:                       "\033[#{31}m",
+  green:                     "\033[#{32}m",
+  yellow:                    "\033[#{33}m",
+  blue:                      "\033[#{34}m",
+  fuchsia:                   "\033[#{35}m",
+  cyan:                      "\033[#{36}m",
+  inv_red:                   "\033[#{41}m",
+  inv_green:                 "\033[#{42}m",
+  inv_yellow:                "\033[#{43}m",
+  inv_blue:                  "\033[#{44}m",
+  inv_fuchsia:               "\033[#{45}m",
+  inv_cyan:                  "\033[#{46}m",
+  b_red:                     "\033[#{91}m",
+  b_green:                   "\033[#{92}m",
+  b_yellow:                  "\033[#{93}m",
+  b_blue:                    "\033[#{94}m",
+  b_fuchsia:                 "\033[#{95}m",
+  b_cyan:                    "\033[#{96}m",
+  off:                       "\033[m"
+}
 DISABLE={
   epub: {
     internal_navigation:     true,
