@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/css.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -428,10 +432,10 @@ WOK
   }
 
   .norm, .bold, .verse, .group, .block, .alt {
-    line-height: 150%;
+    line-height: 133%;
     margin-left: 0em;
     margin-right: 2em;
-    margin-top: 10px;
+    margin-top: 12px;
     margin-bottom: 0px;
     padding-left: 0em;
     text-indent: 0em;
@@ -441,13 +445,13 @@ WOK
     font-family: verdana, arial, georgia, tahoma, sans-serif, helvetica, times, roman;
     font-size: 100%;
     font-weight: normal;
-    line-height: 150%;
+    line-height: 133%;
     text-align: justify;
     margin-left: 0em;
     margin-right: 2em;
     text-indent: 0mm;
-    margin-top: 3px;
-    margin-bottom: 3px;
+    margin-top: 4px;
+    margin-bottom: 4px;
   }
 
   /* indent */
