@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/dal_doc_str.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -233,12 +237,12 @@ module SiSU_DAL_DocumentStructureExtract
               end
             else nil
             end
-          when /^[<\[](?:br)?:(?:pa?r|o(?:bj|---)?)[>\]]\s*$/                  #[br:par] #[br:obj]
+          when /^<(?:br)?:(?:pa?r|o(?:bj|---)?)>\s*$/      #[br:par] #[br:obj]
             SiSU_DAL_DocumentStructure::ObjectLayout.new.break(Hx[:br_obj])
-          when /^(?:[<\[](?:br)?:pg[>\]]|<?:pb>?)\s*$/                         #[br:pg]
-            SiSU_DAL_DocumentStructure::ObjectLayout.new.break(Hx[:br_page])
-          when /^[<\[](?:br)?:pg?n[>\]]\s*$/                                   #[br:pgn]
-            SiSU_DAL_DocumentStructure::ObjectLayout.new.break(Hx[:br_page_new])
+          when /^(?:-\\\\-|<:pb>)\s*$/                                #[br:pg]
+            SiSU_DAL_DocumentStructure::ObjectLayout.new.break(Hx[:br_page],:markup)
+          when /^(?:=\\\\=|<:pn>)\s*$/                                #[br:pgn]
+            SiSU_DAL_DocumentStructure::ObjectLayout.new.break(Hx[:br_page_new],:markup)
           else                                             #paragraph
             image=image_test(t_o)
             note=endnote_test?(t_o)
@@ -363,8 +367,8 @@ module SiSU_DAL_DocumentStructureExtract
             t_o=SiSU_DAL_DocumentStructure::ObjectComment.new.comment(h) #t_o=SiSU_DAL_DocumentStructure::ObjectLayout.new.insert(h)
             t_o
           else
-            if t_o !~/^table\{/ \
-            and not t_o.nil?
+            if t_o.is_a?(String) \
+            and t_o !~/^table\{/
               t_o=t_o.gsub(/^\n+/m,''). #check added for ruby 1.9.2 not needed in 1.8 series (tested in v2)
                 gsub(/\n+/m,"#{Mx[:tc_p]}")
               @rows += t_o + Mx[:tc_c]
@@ -385,8 +389,7 @@ module SiSU_DAL_DocumentStructureExtract
             t_o=SiSU_DAL_DocumentStructure::ObjectComment.new.comment(h) #t_o=SiSU_DAL_DocumentStructure::ObjectLayout.new.insert(h)
           end
           if @@flag['code'] \
-          and t_o.class==String \
-          and not t_o.nil? #you may need to introduce t_o.class==String test more widely
+          and t_o.is_a?(String)
             sub_array=t_o.dup + "#{Mx[:br_nl]}"
             @line_mode=sub_array.scan(/.+/)
             @line_mode=[]
@@ -461,7 +464,7 @@ module SiSU_DAL_DocumentStructureExtract
           if @@flag['poem'] \
           or @@flag['group'] \
           or @@flag['alt']
-            if t_o.class==String
+            if t_o.is_a?(String)
               t_o=t_o.gsub(/\n/m,"#{Mx[:br_nl]}").
                 gsub(/[ ][ ]/m,"#{Mx[:nbsp]*2}").
                 gsub(/#{Mx[:nbsp]}\s/,"#{Mx[:nbsp]*2}")
@@ -527,7 +530,7 @@ module SiSU_DAL_DocumentStructureExtract
       lines.each do |line|
         line=if line =~/\S/ \
         and line !~/^code\{|^\}code/ \
-        and line.class != Hash
+        and not line.is_a?(Hash)
           @@counter+=1 if @@flag['code']
           line=line.gsub(/\s\s/,"#{Mx[:nbsp]*2}").
             gsub(/#{Mx[:nbsp]}\s/,"#{Mx[:nbsp]*2}")
@@ -741,19 +744,19 @@ module SiSU_DAL_DocumentStructureExtract
         elsif dob.obj=~/#{Mx[:pa_non_object_no_heading]}/
           dob.obj=dob.obj.gsub(/#{Mx[:pa_non_object_no_heading]}/,'')
           if dob.is==:para
-            h={ obj: dob.obj, ocn_: false, ocn: nil }
+            h={ obj: dob.obj, ocn_: false, ocn: nil, hang: dob.hang, indent: dob.indent, bullet_: dob.bullet_, tags: dob.tags, parent: dob.parent }
             dob=SiSU_DAL_DocumentStructure::ObjectPara.new.paragraph(h,dob)
           elsif dob.is==:heading
-            h={ obj: dob.obj, ocn_: false, ocn: nil, toc_: true }
+            h={ obj: dob.obj, ocn_: false, ocn: nil, toc_: true, parent: dob.parent }
             dob=SiSU_DAL_DocumentStructure::ObjectHeading.new.heading(h,dob)
           end
         elsif dob.obj=~/#{Mx[:pa_non_object_dummy_heading]}/
           dob.obj=dob.obj.gsub(/#{Mx[:pa_non_object_dummy_heading]}/,'')
           if dob.is==:para
-            h={ obj: dob.obj, ocn_: false, ocn: nil }
+            h={ obj: dob.obj, ocn_: false, ocn: nil, hang: dob.hang, indent: dob.indent, bullet_: dob.bullet_, tags: dob.tags, parent: dob.parent }
             dob=SiSU_DAL_DocumentStructure::ObjectPara.new.paragraph(h,dob)
           elsif dob.is==:heading
-            h={ obj: dob.obj, ocn_: false, ocn: nil, toc_: false }
+            h={ obj: dob.obj, ocn_: false, ocn: nil, toc_: false, parent: dob.parent }
             dob=SiSU_DAL_DocumentStructure::ObjectHeading.new.heading(h,dob)
           end
         else dob
@@ -858,10 +861,9 @@ module SiSU_DAL_DocumentStructureExtract
       tuned_file=tuned_file.flatten
     end
     def tags(o)
-      tag=if o[:status]=='open'
-        %{<#{o[:lv]} id="#{o[:node]}">}
-      else "</#{o[:lv]}>"
-      end
+      tag=(o[:status]=='open') \
+      ? %{<#{o[:lv]} id="#{o[:node]}">}
+      : "</#{o[:lv]}>"
       ln=case o[:lv]
       when 'A'; 1
       when 'B'; 2
