@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/db_columns.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -295,7 +299,7 @@ module SiSU_DbColumns
         end
         def tuple
           t=if defined? @md.creator.author_detail \
-          and @md.creator.author_detail.class==Array \
+          and @md.creator.author_detail.is_a?(Array) \
           and @md.creator.author_detail.length > 0
             txt=''
             @md.creator.author_detail.each do |h|
@@ -366,7 +370,7 @@ module SiSU_DbColumns
         end
         def tuple
           t=if defined? @md.creator.editor_detail \
-          and @md.creator.editor_detail.class==Array \
+          and @md.creator.editor_detail.is_a?(Array) \
           and @md.creator.editor_detail.length > 0
             txt=@md.creator.editor_detail #dc
             txt=''
@@ -394,7 +398,7 @@ module SiSU_DbColumns
         end
         def tuple
           t=if defined? @md.creator.contributor_detail \
-          and @md.creator.contributor_detail.class==Array \
+          and @md.creator.contributor_detail.is_a?(Array) \
           and @md.creator.contributor_detail.length > 0
             txt=@md.creator.contributor_detail #dc
             txt=''
@@ -422,7 +426,7 @@ module SiSU_DbColumns
         end
         def tuple
           t=if defined? @md.creator.illustrator_detail \
-          and @md.creator.illustrator_detail.class==Array \
+          and @md.creator.illustrator_detail.is_a?(Array) \
           and @md.creator.illustrator_detail.length > 0
             txt=@md.creator.illustrator_detail
             txt=''
@@ -450,7 +454,7 @@ module SiSU_DbColumns
         end
         def tuple
           t=if defined? @md.creator.photographer_detail \
-          and @md.creator.photographer_detail.class==Array \
+          and @md.creator.photographer_detail.is_a?(Array) \
           and @md.creator.photographer_detail.length > 0
             txt=@md.creator.photographer_detail
             txt=''
@@ -478,7 +482,7 @@ module SiSU_DbColumns
         end
         def tuple
           t=if defined? @md.creator.translator_detail \
-          and @md.creator.translator_detail.class==Array \
+          and @md.creator.translator_detail.is_a?(Array) \
           and @md.creator.translator_detail.length > 0
             txt=''
             @md.creator.translator_detail.each do |h|
@@ -505,7 +509,7 @@ module SiSU_DbColumns
         end
         def tuple
           t=if defined? @md.creator.prepared_by_detail \
-          and @md.creator.prepared_by_detail.class==Array \
+          and @md.creator.prepared_by_detail.is_a?(Array) \
           and @md.creator.prepared_by_detail.length > 0
             txt=@md.creator.prepared_by_detail
             txt=''
@@ -533,7 +537,7 @@ module SiSU_DbColumns
         end
         def tuple
           t=if defined? @md.creator.digitized_by_detail \
-          and @md.creator.digitized_by_detail.class==Array \
+          and @md.creator.digitized_by_detail.is_a?(Array) \
           and @md.creator.digitized_by_detail.length > 0
             txt=@md.creator.digitized_by_detail
             txt=''
@@ -561,7 +565,7 @@ module SiSU_DbColumns
         end
         def tuple
           t=if defined? @md.creator.audio_detail \
-          and @md.creator.audio_detail.class==Array \
+          and @md.creator.audio_detail.is_a?(Array) \
           and @md.creator.audio_detail.length > 0
             txt=@md.creator.audio_detail
             txt=''
@@ -589,7 +593,7 @@ module SiSU_DbColumns
         end
         def tuple
           t=if defined? @md.creator.video_detail \
-          and @md.creator.video_detail.class==Array \
+          and @md.creator.video_detail.is_a?(Array) \
           and @md.creator.video_detail.length > 0
             txt=''
             @md.creator.video_detail.each do |h|
@@ -1891,7 +1895,7 @@ module SiSU_DbColumns
         end
         def tuple
           t=if defined? @md.dgst \
-          and @md.dgst.class==Array \
+          and @md.dgst.is_a?(Array) \
           and @md.dgst[1]=~/\S+/
             txt=@md.dgst[1]
             ["#{name}, ","'#{txt}', "]
@@ -2025,7 +2029,7 @@ module SiSU_DbColumns
         end
         def tuple
           t=if defined? @md.dgst_skin \
-          and @md.dgst_skin.class==Array \
+          and @md.dgst_skin.is_a?(Array) \
           and @md.dgst_skin[1]=~/\S+/
             txt=@md.dgst_skin[1]
             txt=special_character_escape(txt)
