@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/db_import.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -73,10 +77,12 @@ module SiSU_DbImport
       @cX=SiSU_Screen::Ansi.new(@opt.cmd).cX
       @env=SiSU_Env::InfoEnv.new(@opt.fns)
       @dal="#{@env.processing_path.dal}"
-      if @opt.fns.empty? or @opt.cmd.empty?; @fnb=''
+      @fnb=if @opt.fns.empty? \
+      or @opt.cmd.empty?
+        ''
       else
         @md=SiSU_Param::Parameters.new(@opt).get
-        @fnb=@md.fnb
+        @md.fnb
       end
       @suffix=@opt.fns[/(?:.+?)(?:\.ssm\.sst|\.-?sst)/,1]
       @fnc="#{@dal}/#{@opt.fns}.content.rbm"
@@ -276,16 +282,18 @@ module SiSU_DbImport
               @col[:lev],txt,@col[:ocn],@col[:lev_an],@col[:ocnd],@col[:ocns],@col[:t_of],@col[:t_is],@col[:node],@col[:parent],@col[:digest_clean],@col[:digest_all]=data.ln,data.obj,data.ocn,data.lv,data.odv,data.osp,data.of,data.is,data.node,data.parent,'',''
               @col[:lid]+=1
               txt=endnotes(txt).extract_any
-              @col[:body]=SiSU_FormatShared::CSS_Format.new(@md,data).lev4_minus
-              @col[:body]=special_character_escape(@col[:body])
-              @col[:plaintext]=@col[:body].dup
-              @col[:plaintext]=strip_markup(@col[:plaintext])
-              @col[:plaintext]=clean_searchable_text(@col[:plaintext])
-              if @en[0]; @en_a,@en_z=@en[0].first,@en[0].last
+              body=SiSU_FormatShared::CSS_Format.new(@md,data).lev4_minus
+              @col[:body]=special_character_escape(body)
+              plaintext=@col[:body].dup
+              plaintext=strip_markup(plaintext)
+              @col[:plaintext]=clean_searchable_text(plaintext)
+              book_idx=data.idx ? data.idx : ''
+              @col[:book_idx]=clean_searchable_text(book_idx)
+              if @en[0] then @en_a,@en_z=@en[0].first,@en[0].last
               end
-              if @en_ast[0]; @en_a_asterisk,@en_z_asterisk=@en_ast[0].first,@en_ast[0].last
+              if @en_ast[0] then @en_a_asterisk,@en_z_asterisk=@en_ast[0].first,@en_ast[0].last
               end
-              if @en_pls[0]; @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last
+              if @en_pls[0] then @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last
               end
               t=SiSU_DbTuple::LoadDocuments.new(@conn,@col,@opt,@file_maint)
               @tuple_array << t.tuple
@@ -310,11 +318,13 @@ module SiSU_DbImport
               @env=SiSU_Env::InfoEnv.new(@md.fns)
               @base_url="#{@env.url.root}/#{@md.fnb}/#{@hname}.html"
               txt=endnotes(txt).extract_any
-              @col[:body]=SiSU_FormatShared::CSS_Format.new(@md,data).lev4_plus
-              @col[:body]=special_character_escape(@col[:body])
-              @col[:plaintext]=@col[:body].dup
-              @col[:plaintext]=strip_markup(@col[:plaintext])
-              @col[:plaintext]=clean_searchable_text(@col[:plaintext])
+              body=SiSU_FormatShared::CSS_Format.new(@md,data).lev4_plus
+              @col[:body]=special_character_escape(body)
+              plaintext=@col[:body].dup
+              plaintext=strip_markup(plaintext)
+              @col[:plaintext]=clean_searchable_text(plaintext)
+              book_idx=data.idx ? data.idx : ''
+              @col[:book_idx]=clean_searchable_text(book_idx)
               @en_a,@en_z=@en[0].first,@en[0].last if @en[0]
               @en_a_asterisk,@en_z_asterisk=@en_ast[0].first,@en_ast[0].last if @en_ast[0]
               @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last if @en_pls[0]
@@ -340,11 +350,13 @@ module SiSU_DbImport
               @env=SiSU_Env::InfoEnv.new(@md.fns)
               @base_url="#{@env.url.root}/#{@md.fnb}/#{@hname}.html"
               txt=endnotes(txt).extract_any
-              @col[:body]=SiSU_FormatShared::CSS_Format.new(@md,data).lev4_plus
-              @col[:body]=special_character_escape(@col[:body])
-              @col[:plaintext]=@col[:body].dup
-              @col[:plaintext]=strip_markup(@col[:plaintext])
-              @col[:plaintext]=clean_searchable_text(@col[:plaintext])
+              body=SiSU_FormatShared::CSS_Format.new(@md,data).lev4_plus
+              @col[:body]=special_character_escape(body)
+              plaintext=@col[:body].dup
+              plaintext=strip_markup(plaintext)
+              @col[:plaintext]=clean_searchable_text(plaintext)
+              book_idx=data.idx ? data.idx : ''
+              @col[:book_idx]=clean_searchable_text(book_idx)
               @en_a,@en_z=@en[0].first,@en[0].last if @en[0]
               @en_a_asterisk,@en_z_asterisk=@en_ast[0].first,@en_ast[0].last if @en_ast[0]
               @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last if @en_pls[0]
@@ -368,11 +380,13 @@ module SiSU_DbImport
               @env=SiSU_Env::InfoEnv.new(@md.fns)
               @base_url="#{@env.url.root}/#{@md.fnb}/#{@hname}.html"
               txt=endnotes(txt).extract_any
-              @col[:body]=SiSU_FormatShared::CSS_Format.new(@md,data).lev4_plus
-              @col[:body]=special_character_escape(@col[:body])
-              @col[:plaintext]=@col[:body].dup
-              @col[:plaintext]=strip_markup(@col[:plaintext])
-              @col[:plaintext]=clean_searchable_text(@col[:plaintext])
+              body=SiSU_FormatShared::CSS_Format.new(@md,data).lev4_plus
+              @col[:body]=special_character_escape(body)
+              plaintext=@col[:body].dup
+              plaintext=strip_markup(plaintext)
+              @col[:plaintext]=clean_searchable_text(plaintext)
+              book_idx=data.idx ? data.idx : ''
+              @col[:book_idx]=clean_searchable_text(book_idx)
               @en_a,@en_z=@en[0].first,@en[0].last if @en[0]
               @en_a_asterisk,@en_z_asterisk=@en_ast[0].first,@en_ast[0].last if @en_ast[0]
               @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last if @en_pls[0]
@@ -408,7 +422,7 @@ module SiSU_DbImport
               @en_a,@en_z=@en[0].first,@en[0].last if @en[0]
               @en_a_asterisk,@en_z_asterisk=@en_ast[0].first,@en_ast[0].last if @en_ast[0]
               @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last if @en_pls[0]
-              @col[:body]=if data.is==:table
+              body=if data.is==:table
                 SiSU_FormatShared::CSS_Format.new(@md,data).html_table
               elsif data.is==:code
                 SiSU_FormatShared::CSS_Format.new(@md,data).code
@@ -425,10 +439,12 @@ module SiSU_DbImport
               else
                 SiSU_FormatShared::CSS_Format.new(@md,data).norm
               end
-              @col[:body]=special_character_escape(@col[:body])
-              @col[:plaintext]=@col[:body].dup
-              @col[:plaintext]=strip_markup(@col[:plaintext])
-              @col[:plaintext]=clean_searchable_text(@col[:plaintext])
+              @col[:body]=special_character_escape(body)
+              plaintext=@col[:body].dup
+              plaintext=strip_markup(plaintext)
+              @col[:plaintext]=clean_searchable_text(plaintext)
+              book_idx=data.idx ? data.idx : ''
+              @col[:book_idx]=clean_searchable_text(book_idx)
               t=SiSU_DbTuple::LoadDocuments.new(@conn,@col,@opt,@file_maint)
               @tuple_array << t.tuple
               @en,@en_ast,@en_pls=[],[],[]
