@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/db_remove.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -71,19 +75,21 @@ module SiSU_DbRemove
         : false
       end
       del_id=if driver_sqlite3
-        @conn.get_first_value(%{
+        remove_selected=%{
           SELECT tid
           FROM metadata_and_text
           WHERE src_filename = '#{@opt.fns}'
           AND metadata_and_text.language_document_char = '#{@opt.lng}'
-        ;}).to_i
+        ;}
+        @conn.get_first_value(remove_selected).to_i
       else
-        x=@conn.select_one(%{
+        remove_selected=%{
           SELECT metadata_and_text.tid
           FROM metadata_and_text
           WHERE metadata_and_text.src_filename = '#{@opt.fns}'
           AND metadata_and_text.language_document_char = '#{@opt.lng}'
-        ;})
+        ;}
+        x=@conn.select_one(remove_selected)
         x ? (x.join.to_i) : nil
       end
       if del_id
