@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/digests.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -208,9 +212,9 @@ module SiSU_DigestView
                     if image_source
                       para_image = image_source + '/' + i
                       @image_name << i
-                      @image_dgst << if @dg =~/^sha(?:2|256)$/; sys.sha256(para_image)
-                      else                                      sys.md5(para_image)
-                      end
+                      @image_dgst << (@dg =~/^sha(?:2|256)$/) \
+                      ? sys.sha256(para_image)
+                      : sys.md5(para_image)
                     else
                       @image_name << '  '*16 + i + ' [image missing]'
                       @image_dgst << ''
