@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/epub.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -142,7 +146,6 @@ module SiSU_EPUB
       def tuned_file_instructions
         @tell=SiSU_Screen::Ansi.new(@md.opt.cmd)
         @md.opt.cmd=@md.opt.cmd.gsub(/H/,'h')
-        @md.file_type='html' if @md.opt.cmd =~/[hon]/
         directories
         dal_array=@particulars.dal_array # dal file drawn here
         @tuned_file_array=SiSU_EPUB_Tune::Tune.new(dal_array,@md).songsheet
@@ -200,7 +203,7 @@ module SiSU_EPUB
         @@toc={ seg: [], seg_mini: [], scr: [], ncx: [], opf: [] }
         md_opf_a_content,md_opf_a_spine,md_opf_a_guide=[],[],[]
         @nav_no=0
-        @s_a_no,@s_b_no,@s_c_no=0,0,0
+        @s_a_no,@s_b_no,@s_c_no,@lv5_no,@lv6_no=0,0,0,0,0
         @@toc[:ncx] << @epub.toc_ncx.open #epub ncx navmap
         @@toc[:ncx] << @epub.toc_ncx.head_open << @epub.toc_ncx.head << @epub.toc_ncx.head_close
         @@toc[:ncx] << @epub.toc_ncx.doc_title << @epub.toc_ncx.doc_author
@@ -229,11 +232,13 @@ module SiSU_EPUB
               name_s_a='section_a' + @s_a_no.to_s
               @nav_no+=1
               @nav_no2=@nav_no
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[6]
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[5]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[4]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[3]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[2]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[1]
-              @ncxo[1],@ncxo[2],@ncxo[3],@ncxo[4]=true,false,false,false
+              @ncxo[1],@ncxo[2],@ncxo[3],@ncxo[4],@ncxo[5],@ncxo[6]=true,false,false,false,false,false
               @epub.sections(dob_toc,name_s_a)
               @@toc[:ncx] << @epub.toc_ncx.navpoint(dob_toc,@nav_no,name_s_a) if dob_toc
               if @level_a_first_occurrence \
@@ -251,10 +256,12 @@ module SiSU_EPUB
               name_s_b='section_b' + @s_b_no.to_s
               @nav_no+=1
               @nav_no2=@nav_no
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[6]
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[5]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[4]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[3]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[2]
-              @ncxo[2],@ncxo[3],@ncxo[4]=true,false,false
+              @ncxo[2],@ncxo[3],@ncxo[4],@ncxo[5],@ncxo[6]=true,false,false,false,false
               @epub.sections(dob_toc,name_s_b)
               @@toc[:ncx] << @epub.toc_ncx.navpoint(dob_toc,@nav_no,name_s_b) if dob_toc
               md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc,name_s_b)
@@ -266,9 +273,11 @@ module SiSU_EPUB
               name_s_c='section_c' + @s_c_no.to_s
               @nav_no+=1
               @nav_no3=@nav_no
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[6]
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[5]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[4]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[3]
-              @ncxo[3],@ncxo[4]=true,false
+              @ncxo[3],@ncxo[4],@ncxo[5],@ncxo[6]=true,false,false,false
               @epub.sections(dob_toc,name_s_c)
               @@toc[:ncx] << @epub.toc_ncx.navpoint(dob_toc,@nav_no,name_s_c) if dob_toc
               md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc,name_s_c)
@@ -278,15 +287,39 @@ module SiSU_EPUB
             when 4
               @ncx_cls=[]
               @nav_no+=1
+              @dob_name=dob.name
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[6]
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[5]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[4]
-              @ncxo[4]=true
+              @ncxo[4],@ncxo[5],@ncxo[6]=true,false,false
               @@toc[:ncx] << @epub.toc_ncx.navpoint(dob_toc,@nav_no) if dob_toc
               md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc)
               md_opf_a_spine << @epub.metadata_opf.spine(dob_toc)
               md_opf_a_guide << @epub.metadata_opf.guide(dob_toc)
               SiSU_EPUB::Source::Toc.new(@md,dob_toc).level_4
-            when 5; SiSU_EPUB::Source::Toc.new(@md,dob_toc).level_5
-            when 6; SiSU_EPUB::Source::Toc.new(@md,dob_toc).level_6
+            when 5
+              @ncx_cls=[]
+              name_lv5=@dob_name + '.xhtml' + '#o' + dob_toc.ocn.to_s
+              @nav_no+=1
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[6]
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[5]
+              @ncxo[5],@ncxo[6]=true,false
+              @@toc[:ncx] << @epub.toc_ncx.navpoint(dob_toc,@nav_no,name_lv5) if dob_toc
+              md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc,name_lv5)
+              md_opf_a_spine << @epub.metadata_opf.spine(dob_toc,name_lv5)
+              md_opf_a_guide << @epub.metadata_opf.guide(dob_toc,name_lv5)
+              SiSU_EPUB::Source::Toc.new(@md,dob_toc).level_5
+            when 6
+              @ncx_cls=[]
+              name_lv6=@dob_name + '.xhtml' + '#o' + dob_toc.ocn.to_s
+              @nav_no+=1
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[6]
+              @ncxo[6]=true
+              @@toc[:ncx] << @epub.toc_ncx.navpoint(dob_toc,@nav_no,name_lv6) if dob_toc
+              md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc,name_lv6)
+              md_opf_a_spine << @epub.metadata_opf.spine(dob_toc,name_lv6)
+              md_opf_a_guide << @epub.metadata_opf.guide(dob_toc,name_lv6)
+              SiSU_EPUB::Source::Toc.new(@md,dob_toc).level_6
             else nil
             end
             toc.each do |k,d|
@@ -309,10 +342,13 @@ module SiSU_EPUB
             end
           end
         end
+        @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[6]
+        @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[5]
         @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[4]
         @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[3]
         @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[2]
-        @ncxo[1],@ncxo[2],@ncxo[3],@ncxo[4]=false,false,false,false
+        @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[1]
+        @ncxo[1],@ncxo[2],@ncxo[3],@ncxo[4],@ncxo[5],@ncxo[6]=false,false,false,false,false,false
         md_opf_a_content << @epub.metadata_opf.manifest_images(@md.ec[:image])
         @@toc[:seg] << "</div>\n</div>"
         @@toc[:scr] << "</div>\n</div>"
@@ -336,7 +372,8 @@ module SiSU_EPUB
         and link !~/#/ #% keep eye on link
           p_num=SiSU_EPUB_Format::ParagraphNumber.new(@md,link)
         end
-        title=if dob.obj !~/Document Information/; linkname
+        title=if dob.obj !~/Document Information/
+          linkname
         else
           link='metadata'
           %{<b><a href="#{link}#{Sfx[:epub_xhtml]}">#{linkname}</a></b>}
@@ -357,9 +394,9 @@ module SiSU_EPUB
           end
         else
           @@toc[:scr] <<  '<br />'
-          link=if dob.ln; dob.ln
-          else ''
-          end
+          link=(dob.ln) \
+          ? dob.ln
+          : ''
           %{<b><a href="##{link}">#{linkname}</a></b>}
         end
         txt_obj={ txt: title }
@@ -489,10 +526,6 @@ module SiSU_EPUB
         dochead=dochead.gsub(/toc\.(html)/,'doc.\1') #kludge
         toc_shared << dochead #<< ads.div.major
         segtoc << format_head_toc.head #<< ads.div.major
-        if SiSU_EPUB_Format::HeadToc.method_defined? :toc_head_escript
-          toc_shared << format_head_toc.toc_head_escript
-          segtoc << format_head_toc.toc_head_escript
-        end
         if defined? @md.rights.all \
         and @md.rights.all
           rights=format_head_toc.rights.all
@@ -503,8 +536,6 @@ module SiSU_EPUB
           prefix_b=format_head_toc.prefix_b
           prefix_b=SiSU_EPUB_Tune::CleanXHTML.new(prefix_b).clean
         end
-        seg_toc_band=format_head_toc.seg_head_navigation_band
-        seg_toc_band_bottom=format_head_toc.seg_head_navigation_band_bottom
         tmp_head=nil
         doc_title_endnote=@md.title.full.gsub(/(\*+)/,'<sup><a href="#endnotes">\1</a></sup>')
         tmp_head=doc_title_endnote + "\n"
@@ -521,7 +552,6 @@ module SiSU_EPUB
           toc_shared << format_txt_obj.center_bold
           segtoc << format_txt_obj.center_bold
         end
-        segtoc << seg_toc_band
         tmp_head=nil
         if defined? @md.prefix_a \
         and @md.prefix_a
@@ -552,7 +582,6 @@ module SiSU_EPUB
           segtoc << prefix_b
         end
         #Segtoc tail added here
-        segtoc << seg_toc_band_bottom
         segtoc << format_head_toc.xhtml_close
         segtoc=segtoc.flatten.compact #watch
         SiSU_EPUB::Source::Output.new(@md,segtoc).segtoc
@@ -666,14 +695,14 @@ module SiSU_EPUB
       def segtoc
         begin
           if @make.build.toc?
-            filename_html_index=@make_file.epub.xhtml_index
+            filename_xhtml=@make_file.epub.xhtml_index
             @output.each do |para|
               para=para.strip
               unless para =~/\A\s*\Z/
-                filename_html_index.puts para,"\n"
+                filename_xhtml.puts para,"\n"
               end
             end
-            filename_html_index.close
+            filename_xhtml.close
           end
         rescue
           SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
