@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/epub_format.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -64,8 +68,8 @@ module SiSU_EPUB_Format
       vz=SiSU_Env::GetInit.instance.skin
     end
     def ocn_display
-      @make=SiSU_Env::ProcessingSettings.new(@md)
-      if @make.build.ocn?
+      make=SiSU_Env::ProcessingSettings.new(@md)
+      if make.build.ocn?
         ocn_class='ocn'
         if @ocn.to_i==0
           @ocn.gsub(/^(\d+|)$/,
@@ -92,7 +96,7 @@ module SiSU_EPUB_Format
   end
   class CSS
     def css_epub_xhtml
-<<WOK
+      <<-WOK
 /* SiSU epub css default stylesheet */
   body {
     color: black;
@@ -151,10 +155,10 @@ module SiSU_EPUB_Format
   }
 
   .norm, .bold, .verse, .group, .block, .alt {
-    line-height: 150%;
+    line-height: 133%;
     margin-left: 0em;
     margin-right: 2em;
-    margin-top: 10px;
+    margin-top: 12px;
     margin-bottom: 0px;
     padding-left: 0em;
     text-indent: 0mm;
@@ -164,13 +168,13 @@ module SiSU_EPUB_Format
     font-family: verdana, arial, georgia, tahoma, sans-serif, helvetica, times, roman;
     font-size: 100%;
     font-weight: normal;
-    line-height: 150%;
+    line-height: 133%;
     text-align: justify;
     margin-left: 0em;
     margin-right: 2em;
     text-indent: 0mm;
-    margin-top: 3px;
-    margin-bottom: 3px;
+    margin-top: 4px;
+    margin-bottom: 4px;
   }
   p.norm { }
   p.i1 {padding-left: 1em;}
@@ -1214,7 +1218,7 @@ module SiSU_EPUB_Format
     margin-bottom: 20px;
     margin-right: 15mm;
   }
-WOK
+      WOK
     end
   end
   class HeadInformation
@@ -1232,17 +1236,17 @@ WOK
       @tocband_scroll,@tocband_segtoc=nil,nil
     end
     def doc_type_xhtml
-<<WOK
-<?xml version="1.0" encoding="UTF-8"?>
+      <<-WOK
+<?xml version='1.0' encoding='utf-8'?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
    "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
-WOK
+      WOK
     end
 =begin
 ~/epub
   |-- META-INF
-  |   `-- container.xml                 #✓ simple, make sure full-path of rootfile points to metadata.opf
+  |   `-- container.xml                # simple, make sure full-path of rootfile points to metadata.opf
   |-- content
   |   |-- 1.xhtml
   |   |-- 2.xhtml
@@ -1262,22 +1266,22 @@ WOK
   |   |-- metadata.xhtml
   |   `-- toc.xhtml
   |-- metadata.opf                     #(i) metadata dc; (ii) manifest (contents); (iii) spine (mimetypes)
-  |-- mimetype                         #✓ application/epub+zip
-  `-- toc.ncx                          #✓ (i) head (ii) doc title (iii) navmap, list of navigation points (like chapters)
+  |-- mimetype                         # application/epub+zip
+  `-- toc.ncx                          #(i) head (ii) doc title (iii) navmap, list of navigation points (like chapters)
 =end
     def doc_type
       doc_type_xhtml
     end
     def mimetype
-      <<WOK
+      <<-WOK
 application/epub+zip
-WOK
+      WOK
     end
     def metainf_container #container.xml file in META-INF directory
       #simple, make sure full-path of rootfile points to metadata.opf
       #epub_metadata.opf content.opf
-      <<WOK
-<?xml version="1.0" encoding="UTF-8"?>
+      <<-WOK
+<?xml version='1.0' encoding='utf-8'?>
 <container version="1.0"
   xmlns="urn:oasis:names:tc:opendocument:xmlns:container">
   <rootfiles>
@@ -1285,7 +1289,7 @@ WOK
       media-type="application/oebps-package+xml" />
   </rootfiles>
 </container>
-WOK
+      WOK
     end
     def sections(dob,name)
       filename="#{name}#{Sfx[:epub_xhtml]}"
@@ -1298,16 +1302,17 @@ WOK
     #{dob.obj} -
     #{@md.html_title}
   </title>
-<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
+<meta http-equiv='Content-Type' content='text/html; charset=utf-8' />
 #{@css.xhtml_epub}
 </head>
 #{@vz.color_body}
 <div class="content">
-<div class="substance">
-  <label class="ocn"><a href="#o8" class="lnkocn">8</a></label>
-  <h1 class="norm" id="o8">
-    #{dob.obj}
-  </h1>
+  <div class="substance">
+    <label class="ocn"><a href="#o#{dob.ocn}" class="lnkocn">#{dob.ocn}</a></label>
+    <h1 class="norm" id="o#{dob.ocn}">
+      #{dob.obj}
+    </h1>
+  </div>
 </div>
 </body>
 </html>}
@@ -1327,26 +1332,26 @@ output_epub_cont_seg.close
         close
       end
       def open
-      <<WOK
+        <<-WOK
 <?xml version="1.0"?>
 <!DOCTYPE ncx PUBLIC "-//NISO//DTD ncx 2005-1//EN"
   "http://www.daisy.org/z3986/2005/ncx-2005-1.dtd">
 <ncx xmlns="http://www.daisy.org/z3986/2005/ncx/" version="2005-1">
-WOK
+        WOK
       end
       def close
-      <<WOK
+        <<-WOK
 </ncx>
-WOK
+        WOK
       end
       def head_open
-      <<WOK
+        <<-WOK
   <head>
-WOK
+        WOK
       end
       def head
         depth=@md.lvs[1] + @md.lvs[2] + @md.lvs[3] + @md.lvs[4]
-        <<WOK
+        <<-WOK
     <!-- four required metadata items (for all NCX documents,
       (including the relaxed constraints of OPS 2.0) -->
     <title>#{@md.title.full} by #{@md.author}</title>
@@ -1356,67 +1361,68 @@ WOK
     <meta name="dtb:depth" content="#{depth}" />
     <meta name="dtb:totalPageCount" content="0" />
     <meta name="dtb:maxPageNumber" content="0" />
-WOK
+        WOK
       end
       def head_close
-        <<WOK
+        <<-WOK
   </head>
-WOK
+        WOK
       end
       def doc_title
-        <<WOK
+        <<-WOK
   <docTitle>
     <text>#{@md.title.full}</text>
   </docTitle>
-WOK
+        WOK
       end
       def doc_author
-        <<WOK
+        <<-WOK
   <docAuthor>
     <text>#{@md.author}</text>
   </docAuthor>
-WOK
+        WOK
       end
       def navmap_open
-        <<WOK
+        <<-WOK
   <navMap>
-WOK
+        WOK
       end
       def navmap_sisu_toc(no)
         id_u=DISABLE[:epub][:ncx_navpoint_unique_id] \
         ? ''
         : "-#{no}"
-        <<WOK
+        <<-WOK
     <navPoint id="navpoint#{id_u}" playOrder="#{no}">
       <navLabel>
         <text>Table of Contents</text>
       </navLabel>
       <content src="index#{Sfx[:epub_xhtml]}" />
     </navPoint>
-WOK
+        WOK
       end
       def navpoint(dob,no,name=nil)
         name=name ? name : dob.name
+        cont_name=(name =~/#{Sfx[:epub_xhtml]}/) ? name : (name + Sfx[:epub_xhtml])
         id_u=DISABLE[:epub][:ncx_navpoint_unique_id] \
         ? ''
         : "-#{no}"
-        <<WOK
+        <<-WOK
     <navPoint id="navpoint#{id_u}" playOrder="#{no}">
       <navLabel>
         <text>#{dob.obj}</text>
       </navLabel>
-      <content src="#{name}#{Sfx[:epub_xhtml]}" />
-WOK
+      <content src="#{cont_name}" />
+        WOK
       end
       def navpoint_close
-        <<WOK
+        <<-WOK
     </navPoint>
-WOK
+        WOK
       end
       def navmap_close
-        <<WOK
+        <<-WOK
   </navMap>
-WOK
+        WOK
       end
       self
     end
@@ -1434,15 +1440,15 @@ WOK
         package_close
       end
       def package_open
-        <<WOK
-<?xml version="1.0" encoding="UTF-8"?>
+        <<-WOK
+<?xml version='1.0' encoding='utf-8'?>
 <package xmlns="http://www.idpf.org/2007/opf" unique-identifier="EPB-UUID" version="2.0">
-WOK
+        WOK
       end
       def package_close
-        <<WOK
+        <<-WOK
 </package>
-WOK
+        WOK
       end
       def metadata #metadata dc
         author=if defined? @md.creator.author \
@@ -1562,7 +1568,7 @@ WOK
         else ''
         end
         f=SiSU_Env::FileOp.new(@md)
-        <<WOK
+        <<-WOK
   <metadata xmlns:dc="http://purl.org/dc/elements/1.1/"
     xmlns:opf="http://www.idpf.org/2007/opf"
     unique-identifier="urn:uuid:#{@md.dgst[1]}" version="2.0">
@@ -1572,110 +1578,97 @@ WOK
     <dc:identifier id="bookid">urn:uuid:#{@md.dgst[1]}</dc:identifier>
     <!-- <dc:identifier id="EPB-UUID">urn:uuid:#{@md.dgst[1]}</dc:identifier> -->
   </metadata>
-WOK
+        WOK
       end
       def manifest_open
-        <<WOK
+        <<-WOK
   <manifest>
     <!-- NCX -->
     <item id="ncx" href="#{Ep[:f_ncx]}" media-type="application/x-dtbncx+xml" />
     <!-- CSS Style Sheets -->
     <item id="main-css" href="css/xhtml.css" media-type="text/css" />
     <!-- Content Documents -->
-WOK
+        WOK
       end
       def manifest_content_sisu_toc
-        <<WOK
+        <<-WOK
     <item id="index" href="index.xhtml" media-type="application/xhtml+xml" />
-WOK
+        WOK
       end
       def manifest_content(dob,name=nil)
         name=name ? name : dob.name
-        <<WOK
-    <item id="#{name}" href="#{name}#{Sfx[:epub_xhtml]}" media-type="application/xhtml+xml" />
-WOK
+        href_name=(name =~/#{Sfx[:epub_xhtml]}/) ? name : (name + Sfx[:epub_xhtml])
+        <<-WOK
+    <item id="#{name}" href="#{href_name}" media-type="application/xhtml+xml" />
+        WOK
       end
       def manifest_images(imgs)
         imgs=imgs + ['arrow_next_red.png','arrow_prev_red.png','arrow_up_red.png','bullet_09.png']
         images=["    <!-- Images -->\n"]
         imgs.each do |i|
           image,type=/(\S+?)\.(png|jpg|gif)/.match(i)[1,2]
-          images<<<<WOK
+          images<<<<-WOK
     <item id="#{image}" href="image/#{image}.#{type}" media-type="image/#{type}" />
-WOK
+          WOK
         end
         images=images.join('')
         images
     end
     def manifest_close
-      <<WOK
+      <<-WOK
   </manifest>
-WOK
+        WOK
       end
       def spine_open
         #spine: reading order of XHTML files from manifest, idref attribute refers back to id in manifest (exclude images, CSS etc.).
-        <<WOK
+        <<-WOK
   <spine toc="ncx">
-WOK
+        WOK
       end
       def spine_sisu_toc
-      <<WOK
+        <<-WOK
     <itemref idref="index" linear="yes" />
-WOK
+        WOK
       end
       def spine(dob,name=nil)
         name=name ? name : dob.name
-        <<WOK
+        <<-WOK
     <itemref idref="#{name}" linear="yes" />
-WOK
+        WOK
       end
       def spine_close
-        <<WOK
+        <<-WOK
   </spine>
-WOK
+        WOK
       end
       def guide_open
         #guide: presentation order of XHTML files by reader).
-        <<WOK
+        <<-WOK
   <guide>
-WOK
+        WOK
       end
       def guide_sisu_toc
-      <<WOK
+        <<-WOK
     <reference type="index" href="index#{Sfx[:epub_xhtml]}" />
-WOK
+        WOK
       end
       def guide(dob,name=nil)
         name=name ? name : dob.name
-        <<WOK
-    <reference type="text" href="#{name}#{Sfx[:epub_xhtml]}" />
-WOK
+        guide_name=(name =~/#{Sfx[:epub_xhtml]}/) ? name : (name + Sfx[:epub_xhtml])
+        <<-WOK
+    <reference type="text" href="#{guide_name}" />
+        WOK
       end
       def guide_close
-        <<WOK
+        <<-WOK
   </guide>
-WOK
+        WOK
       end
       self
     end
-    def toc_head_escript
-    end
-    def seg_head_escript
-    end
     def table_close
       %{  </font>
 #{@vz.table_close}}
-    end
-    def buttons_home
-      %{<!- home and index buttons -!>
-  #{@vz.banner_home_and_index_buttons}
-<!- home and index buttons -!>}
-    end
-    def copyat
-      %{<p class="tiny">copy @
-  <a href="#{@vz.url_home}" #{@vz.js_home}>
-    #{@vz.txt_home}
-  </a></p>}
     end
     def xhtml_close
     %{#{@vz.credits_sisu_epub}
@@ -1689,28 +1682,12 @@ WOK
       @md=md
       @tocband_segtoc=make_seg
     end
-    def seg_head_navigation_band
-      firstseg=%{<a href="#{@md.firstseg}#{Sfx[:epub_xhtml]}" target="_top">
-      #{@vz.epub_png_nav_nxt}
-    </a>} if @md.firstseg =~/\S+/
-      DISABLE[:epub][:internal_navigation] \
-      ? ''
-      : %{<p class="align_right">#{firstseg}</p>}
-    end
-    def seg_head_navigation_band_bottom
-      firstseg=%{<a href="#{@md.firstseg}#{Sfx[:epub_xhtml]}" target="_top">
-      #{@vz.epub_png_nav_nxt}
-    </a>} if @md.firstseg =~/\S+/
-      DISABLE[:epub][:internal_navigation] \
-      ? ''
-      : %{<p class="align_right">#{firstseg}</p>}
-    end
     def manifest_link(text)
-  %{ <a href="#{@md.file.output_path.manifest.url}/#{@md.file.base_filename.manifest}" target="_top" #{@vz.js_manifest}>#{text}</a>}
+  %{ <a href="#{@md.file.output_path.manifest.url}/#{@md.file.base_filename.manifest}" target="_top">#{text}</a>}
     end
     def concordance_link(text)
       if @md.concord_make
-  %{<a href="#{@md.file.base_filename.html_concordance}" target="_top" #{@vz.js_concordance}>
+  %{<a href="#{@md.file.base_filename.html_concordance}" target="_top">
       #{text}
     </a>}
       else ''
@@ -1719,17 +1696,16 @@ WOK
     def head
       %{#{doc_type}
 <head>
-<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
+<meta http-equiv='Content-Type' content='text/html; charset=utf-8' />
 #{@css.xhtml_epub}
 </head>
-#{@vz.color_body}
-#{@vz.js_top}}
+#{@vz.color_body}}
     end
     def concordance
       if @md.concord_make
       %{#{@vz.margin_css}
   <h4 class="toc">
-    <a href="./#{@md.file.base_filename.html_concordance}" #{@vz.js_concordance}>
+    <a href="./#{@md.file.base_filename.html_concordance}">
       <i>Concordance</i>
     </a>
   </h4>
@@ -1740,9 +1716,9 @@ WOK
       end
     end
     def links_guide_open(type='horizontal')
-      if type=='vertical'; links_guide_vertical_open
-      else                 links_guide_horizontal_open
-      end
+      (type=='vertical') \
+      ? links_guide_vertical_open
+      : links_guide_horizontal_open
     end
     def prefix_a
     end
@@ -1787,7 +1763,7 @@ WOK
     def metadata
       %{#{@vz.margin_css}
   <h4 class="toc">
-    <a href="#{@metalink}" #{@vz.js_metalink}>
+    <a href="#{@metalink}">
       <i>MetaData</i>
     </a>
   </h4>
@@ -1805,7 +1781,7 @@ WOK
     #{@seg_name_xhtml[@seg_name_xhtml_tracker]} -
     #{@md.html_title}
   </title>
-<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
+<meta http-equiv='Content-Type' content='text/html; charset=utf-8' />
 #{@css.xhtml_epub}
 </head>
 #{@vz.color_body}}
@@ -1838,7 +1814,7 @@ WOK
     attr_accessor :md,:t_o,:txt,:ocn,:format,:table,:link,:linkname,:paranum,:p_num,:headname,:banner,:url
     def initialize(md,t_o)
       @md,@t_o=md,t_o
-      if t_o.class==Hash
+      if t_o.is_a?(Hash)
         @txt            =t_o[:txt]            || nil
         @ocn            =t_o[:ocn]            || nil
         @ocn_display    =t_o[:ocn_display]    || nil
@@ -1853,12 +1829,12 @@ WOK
         if @format and not @format.empty?
           if @format=~/^\d:(\S+)/ #need more reliable marker #if @format =~ /#{Rx[:lv]}/
             headname=$1 #format[/\d~(\S+)/m,1]
-            @headname=if headname =~/^[a-zA-Z]/; %{<id="#{headname}">} #consider: h_#{headname}
-            else %{<id="h#{headname}"></a>}
-            end
-            @headname=if headname =~/^[a-zA-Z]/; %{<a name="#{headname}" id="#{headname}"></a>} #consider: h_#{headname}
-            else %{<a name="h#{headname}" id="h#{headname}"></a>}
-            end
+            @headname=(headname =~/^[a-zA-Z]/) \
+            ? %{<id="#{headname}">}
+            : %{<id="h#{headname}"></a>}
+            @headname=(headname =~/^[a-zA-Z]/) \
+            ? %{<a name="#{headname}" id="#{headname}"></a>}
+            : %{<a name="h#{headname}" id="h#{headname}"></a>}
           end
         end
       elsif t_o.class.inspect =~/Object/
