@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/epub_segments.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -271,9 +275,9 @@ WOK
             @@get_hash_to=dob.name
             @@get_hash_fn=dob.name
           end
-          if dob.obj.class==String
+          if dob.obj.is_a?(String)
             markup(dob)
-          elsif dob.obj.class==Array
+          elsif dob.obj.is_a?(Array)
             dob.obj.each do |pg|
               markup(pg)
             end
@@ -298,9 +302,9 @@ WOK
         and @md.creator.author
           @author=%{<b>#{@md.creator.author}</b>\n}
         end
-        ocn=if @@heading1[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]; $1 #fix
-        else ''
-        end
+        ocn=(@@heading1[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]) \
+        ? $1
+        : ''
         @p_num=SiSU_EPUB_Format::ParagraphNumber.new(@md,ocn)
         txt_obj={ txt: @@heading1, ocn_display: @p_num.ocn_display }
         format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,txt_obj)
@@ -309,9 +313,9 @@ WOK
       end
       if @@is2==1
         heading2=@@heading2
-        ocn=if heading2[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]; $1 #fix
-        else ''
-        end
+        ocn=(heading2[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]) \
+        ? $1
+        : ''
         @p_num=SiSU_EPUB_Format::ParagraphNumber.new(@md,ocn)
         txt_obj={ txt: heading2, ocn_display: @p_num.ocn_display }
         format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,txt_obj)
@@ -320,9 +324,9 @@ WOK
       end
       if @@is3==1
         heading3=@@heading3
-        ocn=if heading3[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]; $1 #fix
-        else ''
-        end
+        ocn=(heading3[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]) \
+        ? $1
+        : ''
         @p_num=SiSU_EPUB_Format::ParagraphNumber.new(@md,ocn)
         txt_obj={ txt: heading3, ocn_display: @p_num.ocn_display }
         format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,txt_obj)
@@ -331,9 +335,9 @@ WOK
       end
       if @@is4==1
         heading4=@@heading4
-        ocn=if heading4[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]; $1 #fix
-        else ''
-        end
+        ocn=(heading4[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]) \
+        ? $1
+        : ''
         @p_num=SiSU_EPUB_Format::ParagraphNumber.new(@md,ocn)
         txt_obj={ txt: heading4, ocn_display: @p_num.ocn_display }
         format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,txt_obj)
@@ -359,7 +363,8 @@ WOK
             sto.seg_heading4 # work on see SplitTextObject
           elsif dob.ln==5
             sto.seg_heading5
-          elsif dob.ln==6; sto.seg_heading6
+          elsif dob.ln==6
+            sto.seg_heading6
           end
         elsif dob.is==:para
           if dob.indent \
