@@ -9,7 +9,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -49,6 +49,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/harvest_authors.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -117,7 +121,7 @@ module SiSU_HarvestAuthors
         if para=~ rgx[:date]
           @date=rgx[:date].match(para)[1]
         end
-        break if @title and @subtitle and @author and @date
+        break if @title && @subtitle && @author && @date
       end
       @fulltitle=@subtitle ? (@title + ' - ' + @subtitle) : @title
       if @title \
@@ -157,7 +161,7 @@ module SiSU_HarvestAuthors
         idx_array.each do |idx|
           idx[:author][:last_first_format_a].each do |author|
             author=author.strip
-            if @@the_idx_authors[lang][author].class==NilClass
+            if @@the_idx_authors[lang][author].is_a?(NilClass)
               @@the_idx_authors[lang][author]={ md: [] }
             end
             @@the_idx_authors[lang][author][:md] << { filename: idx[:filename], file: idx[:file], author: idx[:author], title: idx[:title], date: idx[:date], page: idx[:page], lang: idx[:lang] }
@@ -201,7 +205,7 @@ module SiSU_HarvestAuthors
     def html_file_close
       @the_idx.keys.each do |lng|
         @output[lng][:html].close
-        @output[lng][:html_mnt].close if @output[lng][:html_mnt].class==File
+        @output[lng][:html_mnt].close if @output[lng][:html_mnt].is_a?(File)
       end
     end
     def html_print
@@ -305,12 +309,12 @@ WOK
 </html>
 WOK
         @the_idx.keys.each do |lng|
-          @output[lng][:html_mnt] << a if @output[lng][:html_mnt].class==File
+          @output[lng][:html_mnt] << a if @output[lng][:html_mnt].is_a?(File)
           @output[lng][:html] << a
         end
       end
       def do_html(lng,html)
-        @output[lng][:html_mnt] << html if @output[lng][:html_mnt].class==File
+        @output[lng][:html_mnt] << html if @output[lng][:html_mnt].is_a?(File)
         @output[lng][:html] << html
       end
       def do_string_name(lng,attrib,string)
@@ -324,7 +328,7 @@ WOK
           while @letter < f
             if @alph.length > 0
               @letter=@alph.shift
-              if @output[lng][:html_mnt].class==File
+              if @output[lng][:html_mnt].is_a?(File)
                 @output[lng][:html_mnt] << %{\n<p class="letter"><a name="#{@letter}"></p>#{@letter}</a><p class="book_index_lev1"><a name="#{@letter.downcase}"></a></p>}
               end
               @output[lng][:html] << %{\n<p class="letter"><a name="#{@letter}">#{@letter}</a></p><p class="book_index_lev1"><a name="#{@letter.downcase}"></a></p>}
@@ -340,7 +344,7 @@ WOK
             do_string_name(lng,'',a)
             name=a[0].sub(/(.+?)(?:,.+|$)/,'\1').gsub(/\s+/,'_')
             x = %{<p class="author"><a name="#{name}">#{a[0]}</a></p>}
-            if @output[lng][:html_mnt].class==File
+            if @output[lng][:html_mnt].is_a?(File)
               @output[lng][:html_mnt] << x
             end
             @output[lng][:html] << x
@@ -354,15 +358,16 @@ WOK
                 x[:file] + '.' + lng +  '.html'
               elsif @env.output_dir_structure.by? == :filename
                 "../#{x[:file]}/#{x[:page]}"
+              else '' #error
               end
               work=[ "#{x[:date]} #{x[:title]}", %{<p class="publication">#{x[:date]} <a href="#{manifest_at}">#{x[:title]}</a>, #{x[:author][:authors_s]}</p>} ]
-              works<<=(@output[lng][:html_mnt].class==File) \
+              works<<=(@output[lng][:html_mnt].is_a?(File)) \
               ? (work.concat([%{<p class="publication">[<a href="#{x[:file]}.sst">src</a>]&nbsp;&nbsp;#{x[:date]} <a href="file://#{manifest_at}">#{x[:title]}</a>, #{x[:author][:authors_s]} -- [<a href="#{x[:file]}.sst">#{x[:file]}.sst</a>]</p>}]))
               : work
             end
             works.sort_by {|x| x[0]}.each do |x|
               @output[lng][:html] << x[1]
-              @output[lng][:html_mnt] << x[2] if @output[lng][:html_mnt].class==File
+              @output[lng][:html_mnt] << x[2] if @output[lng][:html_mnt].is_a?(File)
             end
           end
         end
