@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/html.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -90,9 +94,9 @@ module SiSU_HTML
         @env=@particulars.env
         loc=@env.url.output_tell
         unless @opt.cmd =~/q/
-          tool=if @opt.cmd =~/[MVvz]/; "#{@env.program.web_browser} file://#{@md.file.output_path.html_seg.dir}/#{@md.file.base_filename.html_segtoc}"
-          else                          "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
-          end
+          tool=(@opt.cmd =~/[MVvz]/) \
+          ? ("#{@env.program.web_browser} file://#{@md.file.output_path.html_seg.dir}/#{@md.file.base_filename.html_segtoc}")
+          : ("[#{@opt.f_pth[:lng_is]}] #{@opt.fno}")
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,'HTML',tool).green_hi_blue
           : SiSU_Screen::Ansi.new(@opt.cmd,'HTML',tool).green_title_hi
@@ -100,15 +104,15 @@ module SiSU_HTML
         end
         SiSU_Env::InfoSkin.new(@md).select
         data=nil
-        @tuned_file_array=SiSU_HTML::Source::HTML_Environment.new(@particulars).tuned_file_instructions
-        data=@tuned_file_array
+        tuned_file_array=SiSU_HTML::Source::HTML_Environment.new(@particulars).tuned_file_instructions
+        data=tuned_file_array
         scr_endnotes=SiSU_HTML::Source::Endnotes.new(data,@md).scroll
         toc=SiSU_HTML::Source::Toc.new(@md,data).songsheet
         links_guide=SiSU_HTML::Source::LinksGuide.new(data,@md).toc
-        data=@tuned_file_array
+        data=tuned_file_array
         scr_toc=SiSU_HTML::Source::ScrollHeadAndSegToc.new(@md,toc,links_guide).in_common #watch
         SiSU_HTML::Source::Seg.new(@md,data).songsheet
-        data=@tuned_file_array
+        data=tuned_file_array
         scr=SiSU_HTML::Source::Scroll.new(@md,data,scr_endnotes).songsheet
         scroll=SiSU_HTML::Source::ScrollOutput.new(scr_toc,scr[:body],scr[:metadata],scr[:owner_details],scr[:tails],@md).publish
         SiSU_HTML::Source::Output.new(scroll,@md).scroll
@@ -143,12 +147,9 @@ module SiSU_HTML
       end
       def tuned_file_instructions
         @tell=SiSU_Screen::Ansi.new(@md.opt.cmd)
-        @md.opt.cmd=@md.opt.cmd.gsub(/H/,'h')
-        @md.file_type='html' if @md.opt.cmd =~/[hw]/
-        newfilename=%{#{@md.file.output_path.html_scroll.dir}/#{@md.file.base_filename.html_segtoc}} if @md.file_type =~/html/
         dal_array=@particulars.dal_array # dal file drawn here
-        @tuned_file_array=SiSU_HTML_Tune::Tune.new(dal_array,@md).songsheet
-        @tuned_file_array
+        tuned_file_array=SiSU_HTML_Tune::Tune.new(dal_array,@md).songsheet
+        tuned_file_array
       end
     end
     class LinksGuide
@@ -167,9 +168,9 @@ module SiSU_HTML
           and @md.lnk
             @md.lnk.each do |l|
               if defined? l[:say]
-                target=if l[:url] !~/^\.(\.)?\//; 'external'
-                else                              '_top'
-                end
+                target=(l[:url] !~/^\.(\.)?\//) \
+                ? 'external'
+                : '_top'
                 s_lnk_url,s_lnk_lnk=l[:url],l[:say]
                 txt_obj={ lnk_url: s_lnk_url, lnk_txt: s_lnk_lnk, target: target }
                 lev_dob_ocn=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
@@ -321,7 +322,7 @@ WOK
         and link !~/#/ #% keep eye on link
           p_num=SiSU_HTML_Format::ParagraphNumber.new(@md,link)
         end
-        title=if dob.obj !~/Metadata/; linkname
+        title=if dob.obj !~/Metadata/ then linkname
         else
           link='metadata'
           %{<b><a href="#{link}#{@md.lang_code_insert}#{Sfx[:html]}">#{linkname}</a></b>}
@@ -350,9 +351,9 @@ WOK
           end
         else
           @@toc[:scr] <<  '<br />'
-          link=if dob.ln; dob.ln
-          else ''
-          end
+          link=(dob.ln) \
+          ? dob.ln
+          : ''
           %{<b><a href="##{link}">#{linkname}</a></b>}
         end
         txt_obj={ txt: title }
@@ -528,8 +529,6 @@ WOK
         ads=SiSU_HTML_Promo::Ad.new(@md)
         toc_shared << dochead << ads.div.major
         @segtoc << format_head_toc.head << ads.div.major
-        toc_shared << format_head_toc.toc_head_escript if SiSU_HTML_Format::HeadToc.method_defined? :toc_head_escript
-        @segtoc << format_head_toc.toc_head_escript if SiSU_HTML_Format::HeadToc.method_defined? :toc_head_escript
         if @make.build.html_top_band?
           toc_shared << format_head_toc.scroll_head_navigation_band
         end
@@ -547,14 +546,16 @@ WOK
         toc_shared << format_head_toc.scroll_head_title_banner_open
         @segtoc << format_head_toc.seg_head_title_banner_open
         tmp_head=nil
-        doc_title_endnote=@md.title.full.gsub(/(\*+)/,'<sup><a href="#endnotes">\1</a></sup>')
+        doc_title_endnote=@md.title.full.gsub(/(\*+)/,
+          '<sup><a href="#endnotes">\1</a></sup>')
         tmp_head=doc_title_endnote + "\n"
         txt_obj={ txt: tmp_head }
         format_txt_obj=SiSU_HTML_Format::FormatTextObject.new(@md,txt_obj)
         toc_shared << format_txt_obj.center_bold
         @segtoc << format_txt_obj.center_bold
         if defined? @md.creator.author
-          creator_endnote=@md.creator.author.gsub(/(\*+)/,%{&nbsp;<sup><a href="#notes">\\1</a></sup>})
+          creator_endnote=@md.creator.author.gsub(/(\*+)/,
+            %{&nbsp;<sup><a href="#notes">\\1</a></sup>})
           tmp_head=creator_endnote + "\n"
           txt_obj={ txt: tmp_head }
           format_txt_obj=SiSU_HTML_Format::FormatTextObject.new(@md,txt_obj)
@@ -609,8 +610,7 @@ WOK
       end
       def publish
         scroll=[]
-        hr='<center><hr width=90% /></center>'
-        scroll << @scr_toc << '<div class="scroll">' << hr << @scr_body << @scr_endnotes << hr << @scr_owner_details << '</div>' << @scr_tails
+        scroll << @scr_toc << '<div class="scroll">' << @scr_body << @scr_endnotes << @scr_owner_details << '</div>' << @scr_tails
         scroll=scroll.flatten.compact #watch
       end
     end
@@ -663,11 +663,9 @@ WOK
         ensure
           @filename_html_segtoc.close
           pwd_set=Dir.pwd
-          idx_lnk=if @o_str.dump_or_redirect?
-            @file.base_filename.manifest
-          else
-            @file.base_filename.html_segtoc
-          end
+          idx_lnk=(@o_str.dump_or_redirect?) \
+          ? @file.base_filename.manifest
+          : @file.base_filename.html_segtoc
           mlnk=@file.base_filename.html_seg_index
           Dir.chdir(@file.output_path.html_seg.dir)
           FileUtils::rm_f(mlnk)
