@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/html_promo.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -98,7 +102,7 @@ module SiSU_HTML_Promo
         elsif @flag[:sk]                                   #promo set in associated skin
           promo_array=@vz.widget_promo
         elsif @flag[:rc]                                   #promo set in rc file
-          promo_array=if @rc['html']['promo'].class==String
+          promo_array=if @rc['html']['promo'].is_a?(String)
             @rc['html']['promo'].split(/[,;]\s*/)
           else @rc['html']['promo']
           end
@@ -406,7 +410,7 @@ WOK
                 adverts << output_form_select(type,id)
               else
                 if defined? @ad[:promo][category][type][id] \
-                and @ad[:promo][category][type][id].class==Array \
+                and @ad[:promo][category][type][id].is_a?(Array) \
                 and @ad[:promo][category][type][id].length > 0
                   adverts << @ad[:promo][category][type][id].join("\n")
                 end
