@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/html_tune.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -101,97 +105,12 @@ module SiSU_HTML_Tune
     end
     def clean
       html=@html
-      str=if html.class==String
+      str=if html.is_a?(String)
         html
       else html.obj
       end
       str=str.gsub(/#{Mx[:gl_o]}(#[0-9]{3})#{Mx[:gl_c]}/u,'&\1;').
-        gsub(/#{Mx[:gl_o]}#([a-z]{2,4})#{Mx[:gl_c]}/u,'&\1;').
-        gsub(/¢/u,'&cent;').    # &#162;
-        gsub(/£/u,'&pound;').   # &#163;
-        gsub(/¥/u,'&yen;').     # &#165;
-        gsub(/§/u,'&sect;').    # &#167;
-        gsub(/©/u,'&copy;').    # &#169;
-        gsub(/ª/u,'&ordf;').    # &#170;
-        gsub(/«/u,'&laquo;').   # &#171;
-        gsub(/®/u,'&reg;').     # &#174;
-        gsub(/°/u,'&deg;').     # &#176;
-        gsub(/±/u,'&plusmn;').  # &#177;
-        gsub(/²/u,'&sup2;').    # &#178;
-        gsub(/³/u,'&sup3;').    # &#179;
-        gsub(/µ/u,'&micro;').   # &#181;
-        gsub(/¶/u,'&para;').    # &#182;
-        gsub(/¹/u,'&sup1;').    # &#185;
-        gsub(/º/u,'&ordm;').    # &#186;
-        gsub(/»/u,'&raquo;').   # &#187;
-        gsub(/¼/u,'&frac14;').  # &#188;
-        gsub(/½/u,'&frac12;').  # &#189;
-        gsub(/¾/u,'&frac34;').  # &#190;
-        gsub(/×/u,'&times;').   # &#215;
-        gsub(/÷/u,'&divide;').  # &#247;
-        gsub(/¿/u,'&iquest;').  # &#191;
-        gsub(/À/u,'&Agrave;').  # &#192;
-        gsub(/Á/u,'&Aacute;').  # &#193;
-        gsub(/Â/u,'&Acirc;').   # &#194;
-        gsub(/Ã/u,'&Atilde;').  # &#195;
-        gsub(/Ä/u,'&Auml;').    # &#196;
-        gsub(/Å/u,'&Aring;').   # &#197;
-        gsub(/Æ/u,'&AElig;').   # &#198;
-        gsub(/Ç/u,'&Ccedil;').  # &#199;
-        gsub(/È/u,'&Egrave;').  # &#200;
-        gsub(/É/u,'&Eacute;').  # &#201;
-        gsub(/Ê/u,'&Ecirc;').   # &#202;
-        gsub(/Ë/u,'&Euml;').    # &#203;
-        gsub(/Ì/u,'&Igrave;').  # &#204;
-        gsub(/Í/u,'&Iacute;').  # &#205;
-        gsub(/Î/u,'&Icirc;').   # &#206;
-        gsub(/Ï/u,'&Iuml;').    # &#207;
-        gsub(/Ð/u,'&ETH;').     # &#208;
-        gsub(/Ñ/u,'&Ntilde;').  # &#209;
-        gsub(/Ò/u,'&Ograve;').  # &#210;
-        gsub(/Ó/u,'&Oacute;').  # &#211;
-        gsub(/Ô/u,'&Ocirc;').   # &#212;
-        gsub(/Õ/u,'&Otilde;').  # &#213;
-        gsub(/Ö/u,'&Ouml;').    # &#214;
-        gsub(/Ø/u,'&Oslash;').  # &#216;
-        gsub(/Ù/u,'&Ugrave;').  # &#217;
-        gsub(/Ú/u,'&Uacute;').  # &#218;
-        gsub(/Û/u,'&Ucirc;').   # &#219;
-        gsub(/Ü/u,'&Uuml;').    # &#220;
-        gsub(/Ý/u,'&Yacute;').  # &#221;
-        gsub(/Þ/u,'&THORN;').   # &#222;
-        gsub(/ß/u,'&szlig;').   # &#223;
-        gsub(/à/u,'&agrave;').  # &#224;
-        gsub(/á/u,'&aacute;').  # &#225;
-        gsub(/â/u,'&acirc;').   # &#226;
-        gsub(/ã/u,'&atilde;').  # &#227;
-        gsub(/ä/u,'&auml;').    # &#228;
-        gsub(/å/u,'&aring;').   # &#229;
-        gsub(/æ/u,'&aelig;').   # &#230;
-        gsub(/ç/u,'&ccedil;').  # &#231;
-        gsub(/è/u,'&egrave;').  # &#232;
-        gsub(/é/u,'&eacute;').  # &#233;
-        gsub(/ê/u,'&ecirc;').   # &#234;
-        gsub(/ë/u,'&euml;').    # &#235;
-        gsub(/ì/u,'&igrave;').  # &#236;
-        gsub(/í/u,'&iacute;').  # &#237;
-        gsub(/î/u,'&icirc;').   # &#238;
-        gsub(/ï/u,'&iuml;').    # &#239;
-        gsub(/ð/u,'&eth;').     # &#240;
-        gsub(/ñ/u,'&ntilde;').  # &#241;
-        gsub(/ò/u,'&ograve;').  # &#242;
-        gsub(/ó/u,'&oacute;').  # &#243;
-        gsub(/ô/u,'&ocirc;').   # &#244;
-        gsub(/õ/u,'&otilde;').  # &#245;
-        gsub(/ö/u,'&ouml;').    # &#246;
-        gsub(/ø/u,'&oslash;').  # &#248;
-        gsub(/ù/u,'&ugrave;').  # &#250;
-        gsub(/ú/u,'&uacute;').  # &#251;
-        gsub(/û/u,'&ucirc;').   # &#252;
-        gsub(/ü/u,'&uuml;').    # &#253;
-        gsub(/þ/u,'&thorn;').   # &#254;
-        gsub(/ÿ/u,'&yuml;').    # &#255;
-        gsub(/ý/u,'&yacute;')
+        gsub(/#{Mx[:gl_o]}#([a-z]{2,4})#{Mx[:gl_c]}/u,'&\1;')
     end
   end
   class Tune
@@ -225,7 +144,7 @@ module SiSU_HTML_Tune
       data_tuned=[]
       #@tuned_file=[]
       data.each do |dob|
-        dob=angle_brackets(dob)
+        dob=amp_angle_brackets(dob)
         dob=endnotes_html(dob)
         dob=url_markup(dob)
         dob=markup(dob)
@@ -322,8 +241,11 @@ module SiSU_HTML_Tune
       end
       dob
     end
-    def angle_brackets(dob)
-      dob.obj=dob.obj.gsub(/<([a-z:\/]+)>/,"#{Dx[:lt_xml]}\\1#{Dx[:gt_xml]}")
+    def amp_angle_brackets(dob)
+      dob.obj=dob.obj.
+        gsub(/&/u,'&amp;').
+        gsub(/<([a-z:\/]+)>/,"#{Dx[:lt_xml]}\\1#{Dx[:gt_xml]}").
+        gsub(/</u,'&lt;').gsub(/>/u,'&gt;')
       dob
     end
     def endnotes_html(dob)
@@ -354,7 +276,7 @@ module SiSU_HTML_Tune
         gsub(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,'<del>\1</del>').
         gsub(/#{Mx[:fa_monospace_o]}(.+?)#{Mx[:fa_monospace_c]}/,'<tt>\1</tt>'). # tt, kbd
         gsub(/#{Mx[:mk_o]}:name#(\S+?)#{Mx[:mk_c]}/,'<a name="\1"></a>').
-        gsub(/^#{Mx[:gl_bullet]}/m,'●&nbsp;&nbsp;').
+        gsub(/#{Mx[:gl_bullet]}/m,'●&nbsp;&nbsp;').
         gsub(/#{Mx[:nbsp]}/,'&nbsp;').
         gsub(/<(p|br)>/,'<\1 />')
       dob=SiSU_HTML_Tune::CleanHTML.new(dob).clean
