@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/manifest.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -87,7 +91,7 @@ module SiSU_Manifest
           url_html="file://#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}"
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,'Manifest',"#{xbrowser} #{url_html}").green_hi_blue
-          : SiSU_Screen::Ansi.new(@opt.cmd,'Manifest',"[#{@opt.f_pth[:lng_is]}] #{@opt.fno}").grey_title_hi
+          : SiSU_Screen::Ansi.new(@opt.cmd,'Manifest',"[#{@opt.f_pth[:lng_is]}]", "#{url_html}").grey_title_grey_blue
           SiSU_Screen::Ansi.new(@opt.cmd,"#{browser} #{url_html}").grey_tab if @opt.cmd =~/v/i
         end
         data=SiSU_HTML::Source::HTML_Environment.new(@particulars).tuned_file_instructions
@@ -111,7 +115,7 @@ module SiSU_Manifest
         @base_url="#{@env.url.root}/#{@fnb}"
         @o_str=SiSU_Env::FileOp.new(md).output_dir_structure
         @image_path=if @o_str.dump_or_redirect?
-          %{./image}
+          './image'
         else
           %{#{@f.path_rel_links.html_scroll_2}_sisu/image_sys}
         end
@@ -155,9 +159,9 @@ module SiSU_Manifest
       end
       def summarize_sources(id,file,pth,rel,url)
         sys=SiSU_Env::SystemCall.new
-        dgst =if @dg =~/^sha(?:2|256)$/; sys.sha256("#{pth}/#{file}")
-        else                             sys.md5("#{pth}/#{file}")
-        end
+        dgst=(@dg =~/^sha(?:2|256)$/) \
+        ? sys.sha256("#{pth}/#{file}")
+        : sys.md5("#{pth}/#{file}")
         SiSU_Screen::Ansi.new(@md.opt.cmd,"#{dgst[1]} #{file}").warn if @md.opt.cmd =~/[vVM]/
         size=(File.size("#{pth}/#{file}")/1024.00).to_s
         kb=/([0-9]+\.[0-9]{0,1})/m.match(size)[1]
@@ -225,13 +229,13 @@ module SiSU_Manifest
         end
       end
       def metadata(id,info)
-        info=info.to_s.gsub(/#{Mx[:br_line]}/,'<br />')
+        info=info.to_s.gsub(/(?:#{Mx[:br_line]}|\\)+/,'<br />')
         @manifest[:html] << %{<tr><th class="left"><p class="bold_left">#{id}:</p></th><td><p class="left">#{info}</p></td></tr>\n}
       end
       def links(url,lnk,target)
-        static=if url =~/^\.\//; url.gsub(/^\.(\.)?/,@base_url)
-        elsif url =~/^\.\.\//;   url.gsub(/^\.(\.)?/,@env.url.root)
-        else                     url
+        static=if url =~/^\.\// then url.gsub(/^\.(\.)?/,@base_url)
+        elsif url =~/^\.\.\//   then url.gsub(/^\.(\.)?/,@env.url.root)
+        else                         url
         end
         @manifest[:html] << %{<tr><th class="right" width=5%><p class="norm">●</p></th><td class="left"><p class="norm"><a href="#{url}">#{lnk}</a></p><p class="tiny">&nbsp;&nbsp;#{@brace_url.xml_open}<a href="#{static}">#{static}</a>#{@brace_url.xml_close}</p></td></tr>\n}
       end
@@ -398,19 +402,19 @@ module SiSU_Manifest
           id,file='Manpage',@f.base_filename.manpage
           summarize(id,file,pth,rel,url)
         end
-        if FileTest.file?(@f.place_file.sqlite_discreet.dir)==true
-          id,file='SQLite3 file',@f.base_filename.sqlite_discreet
-          pth=@f.output_path.sqlite_discreet.dir
-          rel=@f.output_path.sqlite_discreet.rel_sm
-          url=@f.output_path.sqlite_discreet.url
+        if FileTest.file?(@f.place_file.sqlite_discrete.dir)==true
+          id,file='SQLite3 file',@f.base_filename.sqlite_discrete
+          pth=@f.output_path.sqlite_discrete.dir
+          rel=@f.output_path.sqlite_discrete.rel_sm
+          url=@f.output_path.sqlite_discrete.url
           summarize(id,file,pth,rel,url)
         end
         if FileTest.file?(@f.place_file.txt.dir)==true
-        if    @md.opt.cmd =~/a/; id='Plaintext (Unix (UTF-8) with footnotes)'
-        elsif @md.opt.cmd =~/e/; id='Plaintext (Unix (UTF-8) with endnotes)'
-        elsif @md.opt.cmd =~/A/; id='Plaintext (dos (UTF-8) with footnotes)'
-        elsif @md.opt.cmd =~/E/; id='Plaintext (dos (UTF-8) with endnotes)'
-        else                id='Plaintext (UTF-8)'
+        id=if @md.opt.cmd =~/a/ then 'Plaintext (Unix (UTF-8) with footnotes)'
+        elsif @md.opt.cmd =~/e/ then 'Plaintext (Unix (UTF-8) with endnotes)'
+        elsif @md.opt.cmd =~/A/ then 'Plaintext (dos (UTF-8) with footnotes)'
+        elsif @md.opt.cmd =~/E/ then 'Plaintext (dos (UTF-8) with endnotes)'
+        else                         'Plaintext (UTF-8)'
         end
           pth=@f.output_path.txt.dir
           rel=@f.output_path.txt.rel_sm
@@ -697,9 +701,15 @@ WOK
           @manifest[:html] << %{<tr><th class="left"><p class="bold_left">#{@translate.topic_register}:</p></th><td>\n}
           @md.topic_register_array.each do |t|
             t.each_with_index do |st,i|
-              if st.class==Array
+              if st.is_a?(Array)
                 st.each do |v|
-                  @manifest[:html] << %{<p class="it#{i}">#{v}</p>\n}
+                  if v.is_a?(Array)
+                    v.each do |w,i|
+                      @manifest[:html] << %{<p class="it#{i}">#{w}</p>\n}
+                    end
+                  else
+                    @manifest[:html] << %{<p class="it#{i}">#{v}</p>\n}
+                  end
                 end
               else @manifest[:html] << %{<p class="it#{i}">#{st}</p>\n}
               end
@@ -749,9 +759,9 @@ WOK
         and @md.lnk
           @md.lnk.each do |l|
             if defined? l[:say]
-              target=if l[:url] !~/^\.(\.)?\//; 'external'
-              else                              '_top'
-              end
+              target=(l[:url] !~/^\.(\.)?\//) \
+              ? 'external'
+              : '_top'
               url,lnk=l[:url],l[:say]
               unless url.nil? \
               or url.empty?
