@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/plaintext.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -100,7 +104,7 @@ module SiSU_Plaintext
         else 78
         end
         #wrap_width=(defined? md.make.plaintext_wrap) ? md.make.plaintext_wrap : 78
-        SiSU_Plaintext::Source::Scroll.new(dal_array,md,wrap_width).songsheet
+        SiSU_Plaintext::Source::Scroll.new(md,dal_array,wrap_width).songsheet
         SiSU_Env::InfoSkin.new(md).select #watch
       rescue
         SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
@@ -113,10 +117,10 @@ module SiSU_Plaintext
     class Scroll <Source
       require_relative 'defaults'                       # defaults.rb
       require_relative 'shared_txt'                     # shared_txt.rb
-      include SiSU_TextUtils
+        include SiSU_TextUtils
       @@endnotes={ para: [], end: [] }
-      def initialize(data,md,wrap_width)
-        @data,@md,@wrap_width=data,md,wrap_width
+      def initialize(md,data,wrap_width)
+        @md,@data,@wrap_width=md,data,wrap_width
         @env=SiSU_Env::InfoEnv.new(@md.fns)
         @brace_url=SiSU_Viz::Skin.new.url_decoration
         @tab="\t"
@@ -125,11 +129,7 @@ module SiSU_Plaintext
         when /--endnote/; true
         else true
         end
-        @br=case md.opt.mod.inspect
-        when /--dos/; "\r\n"
-        when /--unix/; "\n"
-        else "\n"
-        end
+        @br="\n"
         @plaintext={ body: [], open: [], close: [], head: [], metadata: [], tail: [] }
       end
       def songsheet
@@ -224,8 +224,8 @@ WOK
           n3=lv + 2
         end
         util=nil
-        wrapped=if dob.is ==:para \
-        or dob.is==:heading
+        wrapped=if dob.is==:para \
+        || dob.is==:heading
           if dob.is==:para
             if dob.hang \
             and dob.hang =~/[0-9]/ \
@@ -251,23 +251,21 @@ WOK
           times=wrapped.length
           times=@wrap_width if times > @wrap_width
           @plaintext[:body] << case lv
-          when 1;      wrapped.upcase << @br << Px[:lv1]*times + p_num << @br
-          when 2;      wrapped.upcase << @br << Px[:lv2]*times + p_num << @br
-          when 3;      wrapped.upcase << @br << Px[:lv3]*times + p_num << @br
-          when 4;      wrapped.upcase << @br << Px[:lv4]*times + p_num << @br
-          when 5;      wrapped.upcase << @br << Px[:lv5]*times + p_num << @br
-          when 6;      wrapped.upcase << @br << Px[:lv6]*times + p_num << @br
+          when 1;      wrapped.upcase << @br << Px[:lv1]*times + p_num << @br*2
+          when 2;      wrapped.upcase << @br << Px[:lv2]*times + p_num << @br*2
+          when 3;      wrapped.upcase << @br << Px[:lv3]*times + p_num << @br*2
+          when 4;      wrapped.upcase << @br << Px[:lv4]*times + p_num << @br*2
+          when 5;      wrapped.upcase << @br << Px[:lv5]*times + p_num << @br*2
+          when 6;      wrapped.upcase << @br << Px[:lv6]*times + p_num << @br*2
           end
         else
           @plaintext[:body] << wrapped + p_num << @br # main text, contents, body KEEP
         end
         if @@endnotes[:para] \
         and not @@endnotes_
-          @plaintext[:body] << @br
           @@endnotes[:para].each {|e| @plaintext[:body] << e << @br}
         elsif @@endnotes[:para] \
         and @@endnotes_
-          @plaintext[:body] << @br*2
         end
         @@endnotes[:para]=[]
       end
@@ -326,9 +324,9 @@ WOK
               gsub(/#{Mx[:gl_o]}#092#{Mx[:gl_c]}/,'\\')
           end
           dob.obj=if dob.of==:block                                   # watch
-            dob.obj.gsub(/#{Mx[:gl_o]}●#{Mx[:gl_c]}/,"* ").
-              gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,"\n")
-          else dob.obj.gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,"\n\n")
+            dob.obj.gsub(/#{Mx[:gl_o]}●#{Mx[:gl_c]}/m,"* ").
+              gsub(/\n?#{Mx[:br_line]}\n?|\n?#{Mx[:br_nl]}\n?/m,@br)
+          else dob.obj.gsub(/\n?#{Mx[:br_line]}\n?|\n?#{Mx[:br_nl]}\n?/m,@br*2)
           end
           if dob.is==:code
             dob.obj=dob.obj.gsub(/(^|[^}])_([<>])/m,'\1\2'). # _> _<
@@ -350,7 +348,7 @@ WOK
             p_num=''
             if @env.plaintext_ocn?
               if defined? dob.ocn \
-              and not dob.ocn.nil?
+              and dob.ocn.is_a?(Fixnum)
                 p_num=SiSU_PlaintextFormat::ParagraphNumber.new(dob.ocn).display
               end
             end
@@ -409,18 +407,19 @@ WOK
         @sisu=[]
         emptyline=0
         @content.each do |para|                                                # this is a hack
-          if para.class==Array \
+          if para.is_a?(Array) \
           and para.length > 0
             para.each do |line|
               if line
-                line.gsub!(/\s+$/m,'')
-                line.gsub!(/^\A[ ]*\Z/m,'')
-                if line=~/^\A[ ]*\Z/m
-                  emptyline+=1
-                else emptyline=0
+                line=line.gsub(/[ \t]+$/m,'').
+                  gsub(/^\A[ ]*\Z/m,'')
+                (line=~/^\A\Z/) \
+                ? (emptyline+=1)
+                : emptyline=0
+                if emptyline < 2                     #remove additional empty lines
+                  file_plaintext.puts line
                 end
-                file_plaintext.puts line if emptyline < 2                     #remove extra line spaces (fix upstream)
-               end
+              end
             end
           else file_plaintext.puts para          #unix plaintext # /^([*=-]|\.){5}/
           end
