@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/po4a.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -214,7 +218,7 @@ module SiSU_Po4a
           end
           desc="#{d}#{s_mark}#{instruct}"
           orig=(orig_notes[i].to_s =~/^\^~[\d*+]+/) ? (orig_notes[i].to_s.gsub(/^\^~[\d*+]+/,'^~')) : orig_notes[i].to_s
-          trans=if trn_notes.class==Array \
+          trans=if trn_notes.is_a?(Array) \
           and trn_notes.length==orig_notes.length
             (trn_notes[i].to_s =~/^\^~[\d*+]+/) ? (trn_notes[i].to_s.gsub(/^\^~[\d*+]+/,'^~')) : trn_notes[i].to_s
           else ''
@@ -749,12 +753,12 @@ GSUB
                 #next if data_trn[t].is == :comment
               end
             end
-            if (defined? data_src[s].ocn and data_src[s].ocn.class == Fixnum) \
-            and (defined? data_trn[t].ocn and data_trn[t].ocn.class == Fixnum) \
+            if (defined? data_src[s].ocn and data_src[s].ocn.is_a?(Fixnum)) \
+            and (defined? data_trn[t].ocn and data_trn[t].ocn.is_a?(Fixnum)) \
             and (data_src[s].ocn == data_trn[t].ocn)
               @m_s,@m_t=s,t
-            elsif (defined? data_src[s].ocn and data_src[s].ocn.class == Fixnum) \
-            and (defined? data_trn[t].ocn and data_trn[t].ocn.class == Fixnum) \
+            elsif (defined? data_src[s].ocn and data_src[s].ocn.is_a?(Fixnum)) \
+            and (defined? data_trn[t].ocn and data_trn[t].ocn.is_a?(Fixnum)) \
             and (data_src[s].ocn != data_trn[t].ocn)
               p '--- OCN ---'
               p 'mis-match'
@@ -934,7 +938,7 @@ GSUB
         @sisu=[]
         emptyline=0
         @content.each do |para|                                                # this is a hack
-          if para.class==Array \
+          if para.is_a?(Array) \
           and para.length > 0
             para.each do |line|
               if line
