@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/qrcode.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -117,16 +121,18 @@ module SiSU_QRcode
       def output_metadata
         fn=@f.base_filename.manifest_txt
         mn=''
-        if @md.opt =~/M/
+        if @md.opt.cmd =~/M/
           pt=@f.output_path.manifest.dir
           fn=@f.base_filename.manifest_txt
           manifest=@f.write_file.manifest_txt
         end
         @manifest[:txt].each do |x|
-          manifest << x if @md.opt =~/M/
+          x=x.gsub(/\\\\/m,"\n")
+          puts x if @md.opt.cmd =~/V/
+          manifest << x if @md.opt.cmd =~/M/
           mn += x
         end
-        manifest.close if @md.opt =~/M/
+        manifest.close if @md.opt.cmd =~/M/
         #system(%{
         #  cat  #{pt}/#{fn} | qrencode -s 3 -o qrcm.autonomy_markup0.png
         #})
@@ -166,9 +172,9 @@ WOK
       end
       def summarize_sources(id,file,pth,rel,url)
         sys=SiSU_Env::SystemCall.new
-        dgst =if @dg =~/^sha(?:2|256)$/; sys.sha256("#{pth}/#{file}")
-        else                             sys.md5("#{pth}/#{file}")
-        end
+        dgst=(@dg =~/^sha(?:2|256)$/) \
+        ? (sys.sha256("#{pth}/#{file}"))
+        : (sys.md5("#{pth}/#{file}"))
         SiSU_Screen::Ansi.new(@md.opt.cmd,"#{dgst[1]} #{file}").warn if @md.opt.cmd =~/[vVM]/
         size=(File.size("#{pth}/#{file}")/1024.00).to_s
         kb=/([0-9]+\.[0-9]{0,1})/m.match(size)[1]
@@ -242,9 +248,9 @@ WOK
         @manifest[:txt_title] << %{#{info}\n}
       end
       def links(url,lnk,target)
-        static=if url =~/^\.\//; url.gsub(/^\.(\.)?/,@base_url)
-        elsif url =~/^\.\.\//;   url.gsub(/^\.(\.)?/,@env.url.root)
-        else                     url
+        static=if url =~/^\.\// then url.gsub(/^\.(\.)?/,@base_url)
+        elsif url =~/^\.\.\//   then url.gsub(/^\.(\.)?/,@env.url.root)
+        else                         url
         end
         @manifest[:txt] << %{#{url} #{lnk} #{@brace_url.txt_open}#{static}#{@brace_url.txt_close}\n}
       end
@@ -384,12 +390,12 @@ WOK
           summarize(id,file,pth,rel,url)
         end
         if FileTest.file?(@f.place_file.txt.dir)==true
-        if    @md.opt.cmd =~/a/; id='Plaintext (Unix (UTF-8) with footnotes)'
-        elsif @md.opt.cmd =~/e/; id='Plaintext (Unix (UTF-8) with endnotes)'
-        elsif @md.opt.cmd =~/A/; id='Plaintext (dos (UTF-8) with footnotes)'
-        elsif @md.opt.cmd =~/E/; id='Plaintext (dos (UTF-8) with endnotes)'
-        else                id='Plaintext (UTF-8)'
-        end
+          id=if @md.opt.cmd =~/a/ then 'Plaintext (Unix (UTF-8) with footnotes)'
+          elsif @md.opt.cmd =~/e/ then 'Plaintext (Unix (UTF-8) with endnotes)'
+          elsif @md.opt.cmd =~/A/ then 'Plaintext (dos (UTF-8) with footnotes)'
+          elsif @md.opt.cmd =~/E/ then 'Plaintext (dos (UTF-8) with endnotes)'
+          else                         'Plaintext (UTF-8)'
+          end
           pth=@f.output_path.txt.dir
           rel=@f.output_path.txt.rel_sm
           url=@f.output_path.txt.url
@@ -668,7 +674,7 @@ WOK
 @sp='  '
           @md.topic_register_array.each do |t|
             t.each_with_index do |st,i|
-              if st.class==Array
+              if st.is_a?(Array)
                 st.each do |v|
                   @manifest[:txt] << %{#{@sp*i}#{v}\n}
                 end
