@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/response.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -61,9 +65,9 @@ module SiSU_Response
       response='redo'
       print ask + " ['yes', 'no' or 'quit']: "
       response=File.new('/dev/tty').gets.strip
-      ans=if response=='yes'; true
-      elsif response=='no'; false
-      elsif response =~/^quit|exit$/; exit
+      ans=if response=='yes'         then true
+      elsif response=='no'           then false
+      elsif response =~/^quit|exit$/ then exit
       else puts "[please type: 'yes', 'no' or 'quit']"
         response?(ask)
       end
