@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/screen_text_color.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -69,16 +73,11 @@ module SiSU_Screen
       @color_instruct=txt[0]
       flag=SiSU_Env::InfoProcessingFlag.new
       if @cmd
-        if flag.color                                                              #set default colors on or off -c acts as toggle against this default, if default is off -c turns on, if default is on -c turns off
-          @use_color=if @cmd =~/c/; false
-          else true
-          end
-        else
-          @use_color=if @cmd =~/c/; true
-          else false
-          end
-        end
-        if @cmd =~/k/; @use_color=false
+        #set default colors on or off -c acts as toggle against this default, if default is off -c turns on, if default is on -c turns off
+        @use_color=(flag.color) \
+        ? ((@cmd =~/c/) ? false : true)
+        : ((@cmd =~/c/) ? true : false)
+        if @cmd =~/k/ then @use_color=false # useful color off switch, however, k may be used for something else in future
         end
       else @use_color=false
       end
@@ -254,13 +253,6 @@ module SiSU_Screen
         %{#{@cX.off} } +
         %{#{@cX.cyan}nav only: #{@txt[4]}#{@cX.off}.}
     end
-    def php_numbers
-      puts %{  #{@cX.green}#{@txt[0]}#{@cX.off} #{@cX.cyan}files processed#{@cX.off}. } +
-        %{php_scr only: #{@txt[1]}, } +
-        %{#{@cX.cyan}php_seg only: #{@txt[2]}#{@cX.off}, } +
-        %{joint php scroll & seg: #{@txt[3]}, } +
-        %{php_nav only: #{@txt[4]}}
-    end
     def txt_white
       puts "\t#{@cX.white}#{@txt[0]}#{@cX.off} #{@cX.white}#{@txt[1]}#{@cX.off}"
     end
@@ -348,6 +340,9 @@ module SiSU_Screen
     def grey_title_hi
       puts %{#{@cX.grey_hi}#{@cX.black}#{@txt[0]}#{@cX.off*2} #{@cX.blue}#{@txt[1]}#{@cX.off}}
     end
+    def grey_title_grey_blue
+      puts %{#{@cX.grey_hi}#{@cX.black}#{@txt[0]}#{@cX.off*2} #{@cX.grey}#{@txt[1]}#{@cX.off} #{@cX.blue}#{@txt[2]}#{@cX.off}}
+    end
     def dark_grey_title_hi
       puts %{#{@cX.darkgrey_hi}#{@cX.black}#{@txt[0]}#{@cX.off*2} #{@cX.blue}#{@txt[1]}#{@cX.off}}
     end
@@ -403,9 +398,6 @@ module SiSU_Screen
     def html_output
       puts %{\t#{@cX.grey}#{@txt[0]}#{@cX.off} #{@cX.ruby}->#{@cX.off}\n\t  #{@cX.blue}#{@txt[1]}#{@cX.off}}
     end
-    def php_title
-      puts %{\n#{@cX.green_hi}#{@cX.black}PHP#{@cX.off*2}}
-    end
     def segmented
       puts "\t#{@cX.grey}Seg#{@cX.off} #{@cX.green}#{@txt[0]}#{@cX.off} #{@cX.grey}segments#{@cX.off}"
     end
