@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/shared_markup_alt.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -58,7 +62,7 @@
 module SiSU_TextRepresentation
   class Alter
     def initialize(x)
-      if x.class==String
+      if x.is_a?(String)
         @t_o,@s=nil,x
       else
         @t_o,@s=x,x.obj.dup
@@ -196,7 +200,7 @@ module SiSU_TextRepresentation
   class ModifiedTextPlusHashDigest
     def initialize(md,x)
       @md=md
-      if x.class==String
+      if x.is_a?(String)
         @t_o,@s=nil,x
       else
         @t_o,@s=x,x.obj.dup
