@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/shared_metadata.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -259,12 +263,12 @@ module SiSU_Metadata
         meta << self.meta_para
       end
       if defined? @md.dgst \
-      and @md.dgst.class==Array
+      and @md.dgst.is_a?(Array)
         @tag,@inf,@class='Source Digest',"#{@md.dgst[0]} #{@md.dgst[1]}",'src'
         meta << self.meta_para
       end
       if defined? @md.dgst_skin \
-      and @md.dgst_skin.class==Array
+      and @md.dgst_skin.is_a?(Array)
         @tag,@inf,@class='Skin Digest',"#{@md.dgst_skin[0]} #{@md.dgst_skin[1]}",'src'
         meta << self.meta_para
       end
@@ -288,7 +292,7 @@ module SiSU_Metadata
         meta << self.meta_para
       end
       if defined? @md.generated \
-      and @md.generated.class==Time
+      and @md.generated.is_a?(Time)
         @tag,@inf,@class=tr.last_generated,@md.generated,'date'
         meta << self.meta_para
       end
@@ -734,7 +738,7 @@ module SiSU_Metadata
       @s=str
       def utf8
         if @s \
-        and @s.class==String
+        and @s.is_a?(String)
           @s=@s.gsub(/<br(?: \/)?>/u,Mx[:br_paragraph]).
             gsub(/</um,'&#60;'). # '&lt;'   # &#060;
             gsub(/</um,'&#60;'). # '&lt;'   # &#060;
@@ -908,7 +912,7 @@ WOK
     def odf
       def meta_para
         url_brace=SiSU_Viz::Skin.new.url_decoration
-        if @inf.class==String
+        if @inf.is_a?(String)
           @inf=@inf.gsub(/</,'&lt;').gsub(/>/,'&gt;').
             gsub(/&lt;br(?: \/)?&gt;/,'<br />')
           if @inf =~/&/
@@ -979,7 +983,7 @@ WOK
       @br="\\\\\n"
     end
     def meta_para(tag,inf,sc=true)
-      inf=((inf.class==String && sc) ? spec_char(inf) : inf)
+      inf=((inf.is_a?(String) && sc) ? spec_char(inf) : inf)
       %{\\begin\{bfseries\}#{tag}:\\end\{bfseries\} #{inf}
 }
     end
@@ -1193,7 +1197,7 @@ WOK
         meta << meta_para(tag,inf)
       end
       if defined? @md.dgst \
-      and @md.dgst.class==Array
+      and @md.dgst.is_a?(Array)
         hash_of=spec_char(@md.dgst[0])
         hash_of=word_break_points(hash_of)
         dgst=number_break_points(@md.dgst[1])
@@ -1201,7 +1205,7 @@ WOK
         meta << meta_para(tag,inf,false)
       end
       if defined? @md.dgst_skin \
-      and @md.dgst_skin.class==Array
+      and @md.dgst_skin.is_a?(Array)
         hash_of=spec_char(@md.dgst_skin[0])
         hash_of=word_break_points(hash_of)
         dgst=number_break_points(@md.dgst_skin[1])
@@ -1210,7 +1214,7 @@ WOK
       end
       meta << %{#{@br}\\begin\{bfseries\}Generated \\end\{bfseries\}}
       if defined? @md.generated \
-      and @md.generated.class==Time
+      and @md.generated.is_a?(Time)
         tag,inf=tr.last_generated,@md.generated
         meta << meta_para(tag,inf)
       end
