@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/sitemaps.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -97,10 +101,9 @@ module SiSU_Sitemaps
       end
     end
     def make_file(path,filename)
-      if File.writable?("#{path}/."); File.new("#{path}/#{filename}",'w+')
-      else
-        SiSU_Screen::Ansi.new('',"is the file or directory writable?, could not create #{filename}").warn
-      end
+      (File.writable?("#{path}/.")) \
+      ? (File.new("#{path}/#{filename}",'w+'))
+      : (SiSU_Screen::Ansi.new('',"is the file or directory writable?, could not create #{filename}").warn)
     end
     def output_map(sitemap)
       path=@md.file.output_path.sitemaps.dir
