@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/sst_convert_markup.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -196,7 +200,7 @@ WOK
       and @opt.files.length > 0
         mr=nil
         #%% changes to make m match, r replace      -------------------------->
-        if @opt.mod.inspect =~/--help/; help
+        if @opt.mod.inspect =~/--help/ then help
         elsif @opt.mod.inspect =~/(?:convert|to)[=-](?:xml |sxs|sax|sxd|dom|sxn|node)/
           ext=case @opt.mod.inspect
           when /(?:convert|to)[=-](?:xml|sxs|sax)/; '.sxs.xml'
@@ -272,13 +276,13 @@ WOK
                       end
                     end
                   end
-                  if y=~/^\s*$/; @empty1=true
-                  else           @empty1=false
-                  end
+                  @empty1=(y=~/^\s*$/) \
+                  ? true
+                  : false
                   @file.puts y unless (@empty1==true and @empty2==true)
-                  if y=~/^\s*$/; @empty2=true
-                  else           @empty2=false
-                  end
+                  @empty2=(y=~/^\s*$/) \
+                  ? true
+                  : false
                 end
                 @file.close
               else puts "NO conversion match in #{i}" unless @opt.cmd=~/q/
