@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/sst_to_s_xml_sax.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -427,7 +431,7 @@ WOK
         @sisu=new_file_data.scan(/.+/)
         SiSU_Env::FileOp.new(@md).mkdir
         filename_sxm=SiSU_Env::FileOp.new(@md,@md.fn[:sxs]).mkfile_pwd
-        if filename_sxm.class==File
+        if filename_sxm.is_a?(File)
           @sisu.each {|para| filename_sxm.puts para}
           filename_sxm.close
         else puts 'file not created, is directory writable?'
