@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/texpdf_format.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -719,7 +723,7 @@ module SiSU_TeX_Pdf
     def initialize(md,t_o)
       @md,@t_o=md,t_o
       @env=SiSU_Env::InfoEnv.new(@md.fns)
-      if t_o.class==Hash
+      if t_o.is_a?(Hash)
         @txt =t_o[:txt]            || nil
         @subtitle=t_o[:subtitle]   || nil
         @ps=t_o[:paper_size]       || nil
@@ -1284,8 +1288,7 @@ WOK
           "\\1#{@brace_url.tex_open}\\begin{scriptsize}\\url{\\2}\\end{scriptsize}#{@brace_url.tex_close}\\3") #url matching with decoration <url> positive lookahead, sequence issue with { linked }http://url cannot use \b at start
       end
       str=str.gsub(/<:ee>/,'').
-        gsub(/<!>/,' ').
-      #proposed change, insert, but may be redundant
+        gsub(/<!>/,' ').  #proposed change, insert, but may be redundant
         gsub(/<(br|p)>|<\/\s*(br|p)>|<(br|p)\s*\/>/," #{Tex[:backslash]*2} "). # Work Area
         gsub(/#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}/,'\begin{bfseries}\1 \end{bfseries}').
         gsub(/<h\d+>(.+?)<\/h\d+>/,'\begin{bfseries}\1 \end{bfseries}').
@@ -1578,3 +1581,78 @@ WOK
   end
 end
 __END__
+#ack usepackage texpdf*
+#ack usepackage texpdf* |ack '\{.+?\}'
+#see sisu_texpdf_usepackage.rb
+  alltt.sty
+  amssymb.sty
+  babel.sty
+  boites.sty
+  color.sty
+  endnotes.sty
+  fancyhdr.sty
+  fontspec.sty
+  footmisc.sty
+  graphicx.sty
+  inputenc.sty
+  listings.sty
+  longtable.sty
+  manyfoot.sty
+  multicol.sty
+  parskip.sty
+  polyglossia.sty
+  soul.sty
+  textcomp.sty
+  thumbpdf.sty
+  titlepic.sty
+  ucs.sty
+  ulem.sty
+  url.sty
+  xetex.sty
+  xltxtra.sty
+  xunicode.sty
+---
+texlive-latex-base
+texlive-base
+texlive-latex-extra
+texlive-latex-recommended
+texlive-xetex
+texlive-generic-recommended
+---
+texlive-latex-base:
+    /usr/share/texlive/texmf-dist/tex/generic/babel/babel.sty
+    /usr/share/texlive/texmf-dist/tex/latex/base/alltt.sty
+    /usr/share/texlive/texmf-dist/tex/latex/base/inputenc.sty
+    /usr/share/texlive/texmf-dist/tex/latex/base/textcomp.sty
+    /usr/share/texlive/texmf-dist/tex/latex/fancyhdr/fancyhdr.sty
+    /usr/share/texlive/texmf-dist/tex/latex/graphics/color.sty
+    /usr/share/texlive/texmf-dist/tex/latex/graphics/graphicx.sty
+    /usr/share/texlive/texmf-dist/tex/latex/tools/longtable.sty
+    /usr/share/texlive/texmf-dist/tex/latex/tools/multicol.sty
+---
+texlive-base:
+    /usr/share/texlive/texmf-dist/tex/latex/amsfonts/amssymb.sty
+---
+texlive-latex-extra:
+    /usr/share/texlive/texmf-dist/tex/latex/boites/boites.sty
+    /usr/share/texlive/texmf-dist/tex/latex/endnotes/endnotes.sty
+    /usr/share/texlive/texmf-dist/tex/latex/footmisc/footmisc.sty
+    /usr/share/texlive/texmf-dist/tex/latex/ncctools/manyfoot.sty
+    /usr/share/texlive/texmf-dist/tex/latex/soul/soul.sty
+    /usr/share/texlive/texmf-dist/tex/latex/titlepic/titlepic.sty
+    /usr/share/texlive/texmf-dist/tex/latex/ucs/ucs.sty
+---
+texlive-latex-recommended:
+    /usr/share/texlive/texmf-dist/tex/generic/thumbpdf/thumbpdf.sty
+    /usr/share/texlive/texmf-dist/tex/latex/fontspec/fontspec.sty
+    /usr/share/texlive/texmf-dist/tex/latex/listings/listings.sty
+    /usr/share/texlive/texmf-dist/tex/latex/parskip/parskip.sty
+    /usr/share/texlive/texmf-dist/tex/latex/url/url.sty
+---
+texlive-xetex:
+    /usr/share/texlive/texmf-dist/tex/latex/xltxtra/xltxtra.sty
+    /usr/share/texlive/texmf-dist/tex/xelatex/polyglossia/polyglossia.sty
+    /usr/share/texlive/texmf-dist/tex/xelatex/xunicode/xunicode.sty
+---
+texlive-generic-recommended:
+    /usr/share/texlive/texmf-dist/tex/generic/ulem/ulem.sty
