@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/urls.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -220,8 +224,8 @@ module SiSU_Urls
         def sqlite(x,y)
           SiSU_Screen::Ansi.new(@opt.cmd,"[#{@opt.f_pth[:lng_is]}] -#{x} DBI sqlite","sqlite3 #{@env.path.webserv}/#{@md.opt.f_pth[:pth_stub]}/sisu_sqlite.db").result
         end
-        def sqlite_discreet(x,y)
-          SiSU_Screen::Ansi.new(@opt.cmd,"[#{@opt.f_pth[:lng_is]}] -#{x}","sqlite3 #{@md.file.output_path.sqlite_discreet.dir}/#{@md.file.base_filename.sqlite_discreet}").result
+        def sqlite_discrete(x,y)
+          SiSU_Screen::Ansi.new(@opt.cmd,"[#{@opt.f_pth[:lng_is]}] -#{x}","sqlite3 #{@md.file.output_path.sqlite_discrete.dir}/#{@md.file.base_filename.sqlite_discrete}").result
         end
         self
       end
@@ -278,10 +282,11 @@ module SiSU_Urls
     end
     def urls_select
       unless @opt.cmd =~/q/
-        i="(output manifest) [#{@opt.f_pth[:lng_is]}] #{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}"
+        i1="[#{@opt.f_pth[:lng_is]}]"
+        i2="file://#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}"
         @opt.cmd=~/[MVvz]/ \
         ? SiSU_Screen::Ansi.new(@opt.cmd,'URLs').green_title_hi
-        : SiSU_Screen::Ansi.new(@opt.cmd,'URL',i).grey_title_hi
+        : SiSU_Screen::Ansi.new(@opt.cmd,'URL (output manifest)',i1, i2).grey_title_grey_blue
         SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}").flow if @opt.cmd =~/[MVv]/
       end
       m=/.+\/(?:src\/)?(\S+)/im # m=/.+?\/(?:src\/)?([^\/]+)$/im # m=/.+\/(\S+)/m
@@ -303,8 +308,8 @@ module SiSU_Urls
                 show.db.psql(x,y)
               end
               if x=~/d\s+--sqlite\b|--sql\b/ \
-              and @opt.act[:sqlite_discreet][:set]==:on
-                show.db.sqlite_discreet(x,y)
+              and @opt.act[:sqlite_discrete][:set]==:on
+                show.db.sqlite_discrete(x,y)
               end
               if x=~/d\[iu\]\s+--sqlite\b/ \
               and @opt.act[:sqlite][:set]==:on
