@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/xml_format.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -195,17 +199,9 @@ module SiSU_XML_Format
       @vz=SiSU_Env::GetInit.instance.skin #margin,paragraph,table,banner,url,png,txt,color,font,nav_txt,nav_png,credits,js,php
       @index='index'
     end
-    def toc_head_escript #embedded script in this case PHP
-    end
     def table_close
       '</font> </td></tr></table>'
     end
-    def buttons_home
-      %{\n#{@banner.home_and_index_buttons}\n}
-    end
-    def copyat
-      %{copy @ <a href="#{@url.home}" #{@js.home}>#{@txt.home}</a>}
-    end
     def toc_head
       <<WOK
 <html>
@@ -381,17 +377,6 @@ WOK
     def table_close
       %{  </font>
 #{@vz.table_close}}
-    end
-    def buttons_home
-      %{<!- home and index buttons -!>
-  #{@vz.banner_home_and_index_buttons}
-<!- home and index buttons -!>}
-    end
-    def copyat
-      %{#{@vz.paragraph_font_tiny}copy @
-  <a href="#{@vz.url_home}" #{@vz.js_home}>
-    #{@vz.txt_home}
-  </a></font>}
     end
     def html_close #moved
     %{</body>
@@ -541,8 +526,7 @@ WOK
 #{@vz.color_body}
 <a name="top" id="top"></a>
 <a name="up" id="up"></a>
-<a name="start" id="start"></a>
-#{@vz.js_top}}
+<a name="start" id="start"></a>}
     end
     def links_guide_open(type='horizontal')
       if type=='vertical'; links_guide_vertical_open
@@ -629,7 +613,7 @@ WOK
     def metadata
       %{#{@vz.margin_css}
   <h4 class="toc">
-    <a href="#{@metalink}" #{@vz.js_metalink}>
+    <a href="#{@metalink}">
       <i>MetaData</i>
     </a>
   </h4>
@@ -719,25 +703,24 @@ WOK
 #{@vz.color_body}
 <a name="top" id="top"></a>
 <a name="up" id="up"></a>
-<a name="start" id="start"></a>
-#{@vz.js_top}}
+<a name="start" id="start"></a>}
     end
     def title_banner(title,subtitle,creator)
     end
     def dot_control_pre_next
       %{<table summary="segment hidden control pre and next" width="100%" border="0" cellpadding="0" bgcolor=#{@vz.color_grey_pale} align="center">
 <tr><td align="left">
-  <a href="#{@seg_name_html[@seg_name_html_tracker-1]}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top" #{@vz.js_prev}>
+  <a href="#{@seg_name_html[@seg_name_html_tracker-1]}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top">
     #{@vz.png_nav_dot_pre}
   </a>
 </td>
 <td align="center">
-  <a href="#{@index}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top" #{@vz.js_toc}>
+  <a href="#{@index}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top">
     #{@vz.png_nav_dot_toc}
   </a>
 </td>
 <td align="right">
-  <a href="#{@seg_name_html[@seg_name_html_tracker+1]}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top" #{@vz.js_next}>
+  <a href="#{@seg_name_html[@seg_name_html_tracker+1]}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top">
     #{@vz.png_nav_dot_nxt}
   </a>
 #{@vz.table_close}}
@@ -745,17 +728,17 @@ WOK
     def toc_nav(f_pre=false,f_nxt=false,use=1)
       pre=nxt=''
       toc=%{<td align="center" bgcolor=#{@vz.color_band1}>
-  <a href="#{@index}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top" #{@vz.js_toc}>
+  <a href="#{@index}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top">
     #{@vz.png_nav_toc}
   </a>
 </td>}
       pre=%{<td align="center" bgcolor=#{@vz.color_band1}>
-  <a href="#{@seg_name_html[@seg_name_html_tracker-use]}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top" #{@vz.js_prev}>
+  <a href="#{@seg_name_html[@seg_name_html_tracker-use]}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top">
     #{@vz.png_nav_pre}
   </a>
 </td>} if f_pre==true
       nxt=%{<td align="center" bgcolor=#{@vz.color_band1}>
-  <a href="#{@seg_name_html[@seg_name_html_tracker+1]}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top" #{@vz.js_next}>
+  <a href="#{@seg_name_html[@seg_name_html_tracker+1]}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top">
     #{@vz.png_nav_nxt}
   </a>
 </td>} if f_nxt==true
@@ -935,8 +918,7 @@ WOK
 #{@vz.color_body}
 <a name="top" id="top"></a>
 <a name="up" id="up"></a>
-<a name="start" id="start"></a>
-#{@vz.js_top}}
+<a name="start" id="start"></a>}
     end
     def title_banner(title,subtitle,creator)
       %{
@@ -999,7 +981,7 @@ WOK
     attr_accessor :md,:dob,:txt,:ocn,:format,:table,:link,:linkname,:paranum,:p_num,:headname,:banner,:url
     def initialize(md,t_o)
       @md,@t_o=md,t_o
-      if t_o.class==Hash
+      if t_o.is_a?(Hash)
         @txt            =t_o[:txt]            || nil
         @ocn            =t_o[:ocn]            || nil
         @ocn_display    =t_o[:ocn_display]    || nil
