@@ -8,7 +8,7 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -48,6 +48,10 @@
  * Download:
    <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
+ * Git
+   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v3/xml_tables.rb;hb=HEAD>
+
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
@@ -97,11 +101,9 @@ module SiSU_Tables
         if @parablock =~/#{Mx[:tc_p]}#{Mx[:tc_p]}/u
           @parablock=@parablock.gsub(/#{Mx[:tc_o]}#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+?)#{Mx[:tc_p]}/u,
             %{<tr>
-  <td width="\\1%" valign="top">
-    #{@vz.paragraph_table_xml}<b>}).
+  <td width="\\1%" valign="top"><b>}).
             gsub(/#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+?)#{Mx[:tc_p]}/u,
-              %{</b></td><td width="\\1%" valign="top">
-  #{@vz.paragraph_table_xml}<b>}).
+              %{</b></td><td width="\\1%" valign="top"><b>}).
             gsub(/#{Mx[:tc_c]}/,"</b>\n</td>\n</tr>")
           @@tablehead=0
         end
@@ -109,13 +111,11 @@ module SiSU_Tables
       else
         @parablock=@parablock.gsub(/#{Mx[:tc_o]}#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+?)#{Mx[:tc_p]}/u,
           %{<tr>
-  <td width="\\1%" valign="top">
-    #{@vz.paragraph_table_xml}}).
+  <td width="\\1%" valign="top">}).
           gsub(/#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+?)#{Mx[:tc_p]}/u,
             %{
   </td>
-  <td width="\\1%" valign="top">
-    #{@vz.paragraph_table_xml}}).
+  <td width="\\1%" valign="top">}).
           gsub(/#{Mx[:tc_c]}/,"\n</td>\n</tr>\n")
       end
       @parablock
